#
# spec file for package texlive
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define texlive_version  2015
%define texlive_previous 2014
%define texlive_release  20150521
%define texlive_noarch   105
%define texlive_source   texlive-20150521-source

%define __perl_requires		%{nil}
%define __os_install_post	/usr/lib/rpm/brp-compress \\\
  %(ls /usr/lib/rpm/brp-suse.d/* 2> /dev/null | grep -vE 'symlink|desktop') %{nil}

%if ! %{defined perl_version}
%global perl_version %(rpm -q --qf '%{VERSION}' perl)
%endif
%global perl_versnum %(rpm -q --qf '%{VERSION}' perl | sed 's/\\.//g')

#
# LuaJIT -- does not build nor support all architectures
#	    Current status is available at https://github.com/LuaJIT/LuaJIT
#	    Compare with libs/luajit/LuaJIT-<version>/src/lj_arch.h
#
%ifarch %ix86 x86_64 ppc arm mips
%global         with_LuaJIT 1
%endif
%bcond_with	LuaJIT

#
# poppler -- use system wide libpoppler
#
%if 0%{suse_version} > 1320
%global         with_poppler 1
%endif
%bcond_with	poppler

#
# psutils -- is also available as the package psutils and therefore
#	    not necessary required, enabling the resulting psutils
#	    cause dependency on package collection-fontutils
%bcond_with	psutils

#
# buildbiber -- we build our own biber executable as with this all
#	    architectures can be supported (in theory) and the final
#	    perl dump binary is smaller
#
%global		with_buildbiber 1
%bcond_with	buildbiber

#
# lcdf-typetools -- is also available as the package lcdf-typetools
#	    and therefore we may only require this external package
%global		with_lcdf_typetools 1
%bcond_with	lcdf_typetools

Name:           texlive
Version:        %{texlive_version}.%{texlive_release}
Release:        26.29
Summary:        The TeXLive Formatting System
License:        GPL-2.0+ and GPL-2.0 and GPL-3.0 and LPPL-1.3c and LPPL-1.0 and Artistic-1.0 and Apache-2.0 and MIT and BSD-3-Clause and SUSE-TeX and SUSE-Public-Domain
Group:          Productivity/Publishing/TeX/Base
Url:            http://www.tug.org/texlive/
PreReq:         /usr/bin/perl
PreReq:         /usr/bin/clear
PreReq:         /usr/bin/dialog
PreReq:         coreutils
PreReq:         ed
PreReq:         findutils
PreReq:         grep
PreReq:         sed
PreReq:         %{name}-filesystem >= %{texlive_version}
PreReq:         %{name}-kpathsea-bin >= %{texlive_version}
PreReq:         %{name}-kpathsea >= %{texlive_version}
PreReq:         %{name}-tetex-bin >= %{texlive_version}
PreReq:         %{name}-tetex >= %{texlive_version}
PreReq:         %{name}-texconfig-bin >= %{texlive_version}
PreReq:         %{name}-texconfig >= %{texlive_version}
#!BuildIgnore:  %{name}-kpathsea-bin
#!BuildIgnore:  %{name}-kpathsea
#!BuildIgnore:  %{name}-tetex-bin
#!BuildIgnore:  %{name}-tetex
#!BuildIgnore:  %{name}-texconfig-bin
#!BuildIgnore:  %{name}-texconfig
Requires(post): coreutils
Requires(postun): coreutils
Requires(posttrans): coreutils
Requires(posttrans): ed
Requires(posttrans): findutils
Requires(posttrans): grep
Requires(posttrans): sed
Requires(posttrans): %{name}-filesystem >= %{texlive_version}
Requires(posttrans): %{name}-kpathsea-bin >= %{texlive_version}
Requires(posttrans): %{name}-kpathsea >= %{texlive_version}
Requires(posttrans): %{name}-tetex-bin >= %{texlive_version}
Requires(posttrans): %{name}-tetex >= %{texlive_version}
Requires(posttrans): %{name}-texconfig-bin >= %{texlive_version}
Requires(posttrans): %{name}-texconfig >= %{texlive_version}
Recommends:     %{name}-scheme-medium
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  cairo
BuildRequires:  cairo-devel
BuildRequires:  dejavu
BuildRequires:  dialog
BuildRequires:  ed
BuildRequires:  expat
BuildRequires:  fdupes
BuildRequires:  fftw3-devel
BuildRequires:  flex
BuildRequires:  freeglut-devel
BuildRequires:  freetype-devel
BuildRequires:  freetype2-devel
BuildRequires:  gc-devel
BuildRequires:  gcc-c++
BuildRequires:  gd-devel
BuildConflicts: ghostscript-mini
BuildRequires:  %{name}-filesystem
BuildRequires:  ghostscript-devel
BuildRequires:  ghostscript-library
BuildRequires:  glibc-devel
%if 0%{suse_version} > 1220
BuildRequires:  glu-devel
%endif
BuildRequires:  graphite2-devel
BuildRequires:  gsl-devel
BuildRequires:  harfbuzz-devel
BuildRequires:  jpeg
BuildRequires:  libicu-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libopenssl-devel
%if 0%{suse_version} > 1220
BuildRequires:  Mesa-libGL-devel
BuildRequires:  Mesa-libglapi-devel
BuildRequires:  libOSMesa-devel
%else
BuildRequires:  Mesa-devel
%endif
BuildRequires:  libpaper-devel
BuildRequires:  libpng-devel
BuildRequires:  libpoppler-devel
%if 0%{suse_version} > 1230
BuildRequires:  libsigsegv-devel
%endif
BuildRequires:  libxml2-devel
BuildRequires:  libxslt-devel
BuildRequires:  mpfr-devel
BuildRequires:  ncurses-devel
BuildRequires:  netpbm
BuildRequires:  pango-devel
BuildRequires:  pango-tools
BuildRequires:  potrace-devel
BuildRequires:  pwdutils
BuildRequires:  readline-devel
BuildConflicts: texinfo
BuildRequires:  unzip
BuildRequires:  xaw3d-devel
BuildRequires:  xorg-x11-devel
BuildRequires:  xorg-x11-util-devel
BuildRequires:  xz
BuildRequires:  zip
BuildRequires:  zlib-devel
BuildRequires:  zziplib-devel
%if %{with buildbiber}
BuildRequires:  perl(autovivification)
#BuildRequires: perl(Business::ISBN)
BuildRequires:  perl-Business-ISBN
BuildRequires:  perl-Business-ISBN-Data
BuildRequires:  perl(Business::ISMN)
BuildRequires:  perl(Business::ISSN)
BuildRequires:  perl(Config::AutoConf) >= 0.15
BuildRequires:  perl(Data::Compare)
BuildRequires:  perl(Data::Dump)
BuildRequires:  perl(Date::Simple)
BuildRequires:  perl(Encode::EUCJPASCII)
BuildRequires:  perl(Encode::HanExtra)
BuildRequires:  perl(Encode::JIS2K)
BuildRequires:  perl(ExtUtils::LibBuilder) >= 0.02
BuildRequires:  perl(File::Slurp::Unicode)
BuildRequires:  perl(File::Which)
BuildRequires:  perl(IPC::Cmd)
BuildRequires:  perl(IPC::Run3)
BuildRequires:  perl(LWP::Protocol::https)
BuildRequires:  perl(LWP::Simple)
BuildRequires:  perl(LWP::UserAgent)
BuildRequires:  perl(List::AllUtils)
BuildRequires:  perl(List::MoreUtils) >= 0.407
BuildRequires:  perl(List::MoreUtils::XS)
BuildRequires:  perl(Log::Log4perl)
BuildRequires:  perl(Module::Build)
%if 0%{suse_version} <= 1230
BuildRequires:  perl(PAR::Packer)
%endif
BuildRequires:  perl(Readonly::XS)
BuildRequires:  perl(Regexp::Common)
BuildRequires:  perl(Test::Differences)
BuildRequires:  perl(Test::More)
BuildRequires:  perl(Test::Pod) >= 1.22
BuildRequires:  perl(Test::Pod::Coverage) >= 1.08
BuildRequires:  perl(Text::BibTeX) >= 0.70
BuildRequires:  perl(Text::Roman)
BuildRequires:  perl(Unicode::Collate) >= 1.12
BuildRequires:  perl(Unicode::GCString)
BuildRequires:  perl(Unicode::Normalize) >= 1.23
BuildRequires:  perl(XML::LibXML::Simple)
BuildRequires:  perl(XML::LibXSLT)
BuildRequires:  perl(XML::Writer::String)
%endif
# Download at ftp://tug.org/texlive/historic/%{texlive_version}/
Source0:        %{texlive_source}.tar.xz
Source3:        biblatex-biber-2.1.tar.xz
Source4:        cnf-to-paths.awk
Source30:       texlive-rpmlintrc
Source50:       public.c
Source51:       public.8
Patch0:         source.dif
Patch1:         source-configure.dif
Patch2:         source-xdvizilla.dif
Patch3:         source-arraysubs.dif
Patch5:         source-texdoc.dif
Patch6:         source-dviutils.dif
Patch7:         source-xdvik-events.dif
Patch8:         source-psutils.dif
Patch10:        source-poppler.dif
Patch11:        source-lacheck.dif
Patch12:        source-warns.dif
Patch13:        source-x11r7.dif
# PATCH-EXTEND-UPSTREAM source-maxpath.dif
Patch14:        source-maxpath.dif
Patch15:        source-overflow.dif
Patch17:        source-64.dif
Patch18:        source-a2ping.dif
Patch19:        source-dvipng.dif
Patch20:        source-missed-scripts.dif
# PATCH-FIX-SUSE Make biber work with our perl
Patch42:        biblatex-encoding.dif
# PATCH-FIX-SUSE Make biber work with perl 5.22
Patch43:        biber-perl-5.22.dif
# PATCH-FIX-SUSE Old problem back: we do not use internal Certs!
Patch44:        biber-certs.dif
# PATCH-FIX-UPSTREAM Use newer Unicode::Normalize as this supports XS again
Patch45:        biber-perl-unicode-normalize.dif
# PATCH-FIX-UPSTREAM Removed old forms tests
Patch46:        biber-skip-bibtex-forms.dif
# PATCH-FIX-SUSE Make biber work with perl 5.18.2
Patch47:        biber-perl-5.18.2.dif
Prefix:         %{_bindir}
Provides:       pdfjam = %{version}
Obsoletes:      pdfjam < %{version}

%{expand: %%global options %(mktemp /tmp/texlive-opts.XXXXXXXX)}
%global _varlib		%{_localstatedir}/lib
%global _libexecdir	%{_prefix}/lib

%define _texmfdistdir	%{_datadir}/texmf
%if 0%{texlive_version} >= 2013
%define _texmfmaindir	%{_texmfdistdir}
%define _texmfdirs	%{_texmfdistdir}
%else
%define _texmfmaindir	%{_libexecdir}/texmf
%define _texmfdirs	\{%{_texmfdistdir},%{_texmfmaindir}\}
%endif

%define _texmfconfdir	%{_sysconfdir}/texmf
%define _texmfvardir	%{_varlib}/texmf
%define _texmfcache	%{_localstatedir}/cache/texmf
%define _fontcache	%{_texmfcache}/fonts
#
%define _x11bin		%{_prefix}/bin
%define _x11lib		%{_libdir}
%define _x11data	%{_datadir}/X11
%define _x11inc		%{_includedir}
%define _appdefdir	%{_x11data}/app-defaults
#
%define texgrp		mktex
#%define texgid		505
#
%description
After installing texlive and the package texlive-latex, find a large
selection of documentation for TeX, LaTeX, and various layout styles in
/usr/share/texmf/doc.

TeX (pronounced tech) is an interpreter for text formatting and was
developed by Donald E. Knuth.  It works with control and macro commands
on a text file. Working with TeX is similar to typesetting methods.
LaTeX is a complex macro package that removes the cryptical TeX
interface and does most of the work for the user.

TeX uses special fonts produced by the MetaFont program. Various
printer drivers and an X11 viewer are also included in this package.
The teTeX package is based on the standard TeX package of Karl Berry,
which makes configuration much easier. It is also possible to use
PostScript fonts. A real PostScript printer is required, however. If
the ghostscript (gs) package is installed, all drivers for printing and
viewing can use these fonts. Note, however, that the fonts included in
the ghostscript package are not identical to Adobe's PostScript fonts.
The copyright prohibids us to include them on the CD.

Besides these features, the programs MakeIndex (for producing indexes)
and BibTeX (for literature data processing) exist.

The texlive package includes a full texmf tree, many programs like tex,
dvips, etc., shell script configuration, and a big collection of
documentations. This package is easily configured by the script
texconfig and has multilanguage options.


%package a2ping-bin
Version:        %{texlive_version}.%{texlive_release}.svn27321
Release:        26.29
Summary:        Binary files of a2ping
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-a2ping >= %{texlive_version}
#!BuildIgnore:  texlive-a2ping
Prefix:         %{_bindir}

%description a2ping-bin
Binary files of a2ping

%package accfonts-bin
Version:        %{texlive_version}.%{texlive_release}.svn12688
Release:        26.29
Summary:        Binary files of accfonts
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-accfonts >= %{texlive_version}
#!BuildIgnore:  texlive-accfonts
Prefix:         %{_bindir}

%description accfonts-bin
Binary files of accfonts

%package adhocfilelist-bin
Version:        %{texlive_version}.%{texlive_release}.svn28038
Release:        26.29
Summary:        Binary files of adhocfilelist
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-adhocfilelist >= %{texlive_version}
#!BuildIgnore:  texlive-adhocfilelist
Prefix:         %{_bindir}

%description adhocfilelist-bin
Binary files of adhocfilelist

%package afm2pl-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of afm2pl
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-afm2pl >= %{texlive_version}
#!BuildIgnore:  texlive-afm2pl
Prefix:         %{_bindir}

%description afm2pl-bin
Binary files of afm2pl

%package aleph-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of aleph
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-aleph >= %{texlive_version}
#!BuildIgnore:  texlive-aleph
Prefix:         %{_bindir}

%description aleph-bin
Binary files of aleph

%package amstex-bin
Version:        %{texlive_version}.%{texlive_release}.svn3006
Release:        26.29
Summary:        Binary files of amstex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-amstex >= %{texlive_version}
#!BuildIgnore:  texlive-amstex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description amstex-bin
Binary files of amstex

%package arara-bin
Version:        %{texlive_version}.%{texlive_release}.svn29036
Release:        26.29
Summary:        Binary files of arara
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-arara >= %{texlive_version}
#!BuildIgnore:  texlive-arara
Prefix:         %{_bindir}

%description arara-bin
Binary files of arara

%package asymptote-bin
Version:        %{texlive_version}.%{texlive_release}.svn37459
Release:        26.29
Summary:        Binary files of asymptote
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-asymptote >= %{texlive_version}
#!BuildIgnore:  texlive-asymptote
Prefix:         %{_bindir}

%description asymptote-bin
Binary files of asymptote

%package authorindex-bin
Version:        %{texlive_version}.%{texlive_release}.svn18790
Release:        26.29
Summary:        Binary files of authorindex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-authorindex >= %{texlive_version}
#!BuildIgnore:  texlive-authorindex
Prefix:         %{_bindir}

%description authorindex-bin
Binary files of authorindex

%package biber-bin
Version:        %{texlive_version}.%{texlive_release}.svn37327
Release:        26.29
Summary:        Binary files of biber
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
%if %{with buildbiber}
Requires:       perl = %{perl_version}
Recommends:     ca-certificates
Recommends:     ca-certificates-mozilla
%if 0%{suse_version} > 1230
Requires:       perl(Biber) >= %{texlive_version}.%{texlive_release}
%endif
Requires:       perl(LWP::UserAgent)
Requires:       perl(Text::BibTeX)
Requires:       perl(Text::Roman)
%endif
BuildArch:      noarch
Requires(pre):  texlive-biber >= %{texlive_version}
#!BuildIgnore:  texlive-biber
Prefix:         %{_bindir}

%description biber-bin
Binary files of biber

%package bibexport-bin
Version:        %{texlive_version}.%{texlive_release}.svn16219
Release:        26.29
Summary:        Binary files of bibexport
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-bibexport >= %{texlive_version}
#!BuildIgnore:  texlive-bibexport
Prefix:         %{_bindir}

%description bibexport-bin
Binary files of bibexport

%package bibtex-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of bibtex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-bibtex >= %{texlive_version}
#!BuildIgnore:  texlive-bibtex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description bibtex-bin
Binary files of bibtex

%package bibtex8-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of bibtex8
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-bibtex8 >= %{texlive_version}
#!BuildIgnore:  texlive-bibtex8
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description bibtex8-bin
Binary files of bibtex8

%package bibtexu-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of bibtexu
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-bibtexu >= %{texlive_version}
#!BuildIgnore:  texlive-bibtexu
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description bibtexu-bin
Binary files of bibtexu

%package bundledoc-bin
Version:        %{texlive_version}.%{texlive_release}.svn17794
Release:        26.29
Summary:        Binary files of bundledoc
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-bundledoc >= %{texlive_version}
#!BuildIgnore:  texlive-bundledoc
Prefix:         %{_bindir}

%description bundledoc-bin
Binary files of bundledoc

%package cachepic-bin
Version:        %{texlive_version}.%{texlive_release}.svn15543
Release:        26.29
Summary:        Binary files of cachepic
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-cachepic >= %{texlive_version}
#!BuildIgnore:  texlive-cachepic
Prefix:         %{_bindir}

%description cachepic-bin
Binary files of cachepic

%package checkcites-bin
Version:        %{texlive_version}.%{texlive_release}.svn25623
Release:        26.29
Summary:        Binary files of checkcites
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-checkcites >= %{texlive_version}
#!BuildIgnore:  texlive-checkcites
Prefix:         %{_bindir}

%description checkcites-bin
Binary files of checkcites

%package chktex-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of chktex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-chktex >= %{texlive_version}
#!BuildIgnore:  texlive-chktex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description chktex-bin
Binary files of chktex

%package cjk-gs-integrate-bin
Version:        %{texlive_version}.%{texlive_release}.svn37223
Release:        26.29
Summary:        Binary files of cjk-gs-integrate
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-cjk-gs-integrate >= %{texlive_version}
#!BuildIgnore:  texlive-cjk-gs-integrate
Prefix:         %{_bindir}

%description cjk-gs-integrate-bin
Binary files of cjk-gs-integrate

%package cjkutils-bin
Version:        %{texlive_version}.%{texlive_release}.svn36924
Release:        26.29
Summary:        Binary files of cjkutils
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Obsoletes:      texlive-bin-cjk <= %{texlive_previous}
Requires(pre):  texlive-cjkutils >= %{texlive_version}
#!BuildIgnore:  texlive-cjkutils
Prefix:         %{_bindir}

%description cjkutils-bin
Binary files of cjkutils

%package context-bin
Version:        %{texlive_version}.%{texlive_release}.svn34112
Release:        26.29
Summary:        Binary files of context
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-context >= %{texlive_version}
#!BuildIgnore:  texlive-context
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-context >= %{texlive_version}
Prefix:         %{_bindir}

%description context-bin
Binary files of context

%package convbkmk-bin
Version:        %{texlive_version}.%{texlive_release}.svn30408
Release:        26.29
Summary:        Binary files of convbkmk
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-convbkmk >= %{texlive_version}
#!BuildIgnore:  texlive-convbkmk
Prefix:         %{_bindir}

%description convbkmk-bin
Binary files of convbkmk

%package crossrefware-bin
Version:        %{texlive_version}.%{texlive_release}.svn35401
Release:        26.29
Summary:        Binary files of crossrefware
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-crossrefware >= %{texlive_version}
#!BuildIgnore:  texlive-crossrefware
Prefix:         %{_bindir}

%description crossrefware-bin
Binary files of crossrefware

%package cslatex-bin
Version:        %{texlive_version}.%{texlive_release}.svn3006
Release:        26.29
Summary:        Binary files of cslatex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-cslatex >= %{texlive_version}
#!BuildIgnore:  texlive-cslatex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-latexrecommended >= %{texlive_version}
Prefix:         %{_bindir}

%description cslatex-bin
Binary files of cslatex

%package csplain-bin
Version:        %{texlive_version}.%{texlive_release}.svn33902
Release:        26.29
Summary:        Binary files of csplain
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-csplain >= %{texlive_version}
#!BuildIgnore:  texlive-csplain
Prefix:         %{_bindir}

%description csplain-bin
Binary files of csplain

%package ctanify-bin
Version:        %{texlive_version}.%{texlive_release}.svn24061
Release:        26.29
Summary:        Binary files of ctanify
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-ctanify >= %{texlive_version}
#!BuildIgnore:  texlive-ctanify
Prefix:         %{_bindir}

%description ctanify-bin
Binary files of ctanify

%package ctanupload-bin
Version:        %{texlive_version}.%{texlive_release}.svn23866
Release:        26.29
Summary:        Binary files of ctanupload
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-ctanupload >= %{texlive_version}
#!BuildIgnore:  texlive-ctanupload
Prefix:         %{_bindir}

%description ctanupload-bin
Binary files of ctanupload

%package ctie-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of ctie
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-ctie >= %{texlive_version}
#!BuildIgnore:  texlive-ctie
Prefix:         %{_bindir}

%description ctie-bin
Binary files of ctie

%package cweb-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of cweb
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-cweb >= %{texlive_version}
#!BuildIgnore:  texlive-cweb
Prefix:         %{_bindir}

%description cweb-bin
Binary files of cweb

%package cyrillic-bin-bin
Version:        %{texlive_version}.%{texlive_release}.svn29741
Release:        26.29
Summary:        Binary files of cyrillic-bin
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-cyrillic-bin >= %{texlive_version}
#!BuildIgnore:  texlive-cyrillic-bin
Prefix:         %{_bindir}

%description cyrillic-bin-bin
Binary files of cyrillic-bin

%package de-macro-bin
Version:        %{texlive_version}.%{texlive_release}.svn17399
Release:        26.29
Summary:        Binary files of de-macro
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-de-macro >= %{texlive_version}
#!BuildIgnore:  texlive-de-macro
Prefix:         %{_bindir}

%description de-macro-bin
Binary files of de-macro

%package detex-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of detex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-detex >= %{texlive_version}
#!BuildIgnore:  texlive-detex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description detex-bin
Binary files of detex

%package devnag-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of devnag
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-devnag >= %{texlive_version}
#!BuildIgnore:  texlive-devnag
Prefix:         %{_bindir}

%description devnag-bin
Binary files of devnag

%package diadia-bin
Version:        %{texlive_version}.%{texlive_release}.svn37645
Release:        26.29
Summary:        Binary files of diadia
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
BuildArch:      noarch
Requires(pre):  texlive-diadia >= %{texlive_version}
#!BuildIgnore:  texlive-diadia
Prefix:         %{_bindir}

%description diadia-bin
Binary files of diadia

%package dosepsbin-bin
Version:        %{texlive_version}.%{texlive_release}.svn24759
Release:        26.29
Summary:        Binary files of dosepsbin
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-dosepsbin >= %{texlive_version}
#!BuildIgnore:  texlive-dosepsbin
Prefix:         %{_bindir}

%description dosepsbin-bin
Binary files of dosepsbin

%package dtl-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of dtl
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-dtl >= %{texlive_version}
#!BuildIgnore:  texlive-dtl
Prefix:         %{_bindir}

%description dtl-bin
Binary files of dtl

%package dtxgen-bin
Version:        %{texlive_version}.%{texlive_release}.svn29031
Release:        26.29
Summary:        Binary files of dtxgen
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-dtxgen >= %{texlive_version}
#!BuildIgnore:  texlive-dtxgen
Prefix:         %{_bindir}

%description dtxgen-bin
Binary files of dtxgen

%package dviasm-bin
Version:        %{texlive_version}.%{texlive_release}.svn8329
Release:        26.29
Summary:        Binary files of dviasm
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-dviasm >= %{texlive_version}
#!BuildIgnore:  texlive-dviasm
Prefix:         %{_bindir}

%description dviasm-bin
Binary files of dviasm

%package dvicopy-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of dvicopy
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-dvicopy >= %{texlive_version}
#!BuildIgnore:  texlive-dvicopy
Prefix:         %{_bindir}

%description dvicopy-bin
Binary files of dvicopy

%package dvidvi-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of dvidvi
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-dvidvi >= %{texlive_version}
#!BuildIgnore:  texlive-dvidvi
Prefix:         %{_bindir}

%description dvidvi-bin
Binary files of dvidvi

%package dviljk-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of dviljk
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Obsoletes:      texlive-bin-dvilj <= %{texlive_previous}
Provides:       texlive-bin-dvilj   = %{texlive_version}
Requires(pre):  texlive-dviljk >= %{texlive_version}
#!BuildIgnore:  texlive-dviljk
Prefix:         %{_bindir}

%description dviljk-bin
Binary files of dviljk

%package dvipdfmx-bin
Version:        %{texlive_version}.%{texlive_release}.svn37207
Release:        26.29
Summary:        Binary files of dvipdfmx
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Obsoletes:      texlive-dvipdfm-bin <= 2012
Provides:       texlive-dvipdfm-bin = %{texlive_version}
Requires(pre):  texlive-dvipdfmx >= %{texlive_version}
#!BuildIgnore:  texlive-dvipdfmx
Prefix:         %{_bindir}

%description dvipdfmx-bin
Binary files of dvipdfmx

%package dvipng-bin
Version:        %{texlive_version}.%{texlive_release}.svn37100
Release:        26.29
Summary:        Binary files of dvipng
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-dvipng >= %{texlive_version}
#!BuildIgnore:  texlive-dvipng
Prefix:         %{_bindir}

%description dvipng-bin
Binary files of dvipng

%package dvipos-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of dvipos
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-dvipos >= %{texlive_version}
#!BuildIgnore:  texlive-dvipos
Prefix:         %{_bindir}

%description dvipos-bin
Binary files of dvipos

%package dvips-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of dvips
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-dvips >= %{texlive_version}
#!BuildIgnore:  texlive-dvips
Prefix:         %{_bindir}

%description dvips-bin
Binary files of dvips

%package dvisvgm-bin
Version:        %{texlive_version}.%{texlive_release}.svn37257
Release:        26.29
Summary:        Binary files of dvisvgm
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-dvisvgm >= %{texlive_version}
#!BuildIgnore:  texlive-dvisvgm
Prefix:         %{_bindir}

%description dvisvgm-bin
Binary files of dvisvgm

%package ebong-bin
Version:        %{texlive_version}.%{texlive_release}.svn21000
Release:        26.29
Summary:        Binary files of ebong
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-ebong >= %{texlive_version}
#!BuildIgnore:  texlive-ebong
Prefix:         %{_bindir}

%description ebong-bin
Binary files of ebong

%package eplain-bin
Version:        %{texlive_version}.%{texlive_release}.svn3006
Release:        26.29
Summary:        Binary files of eplain
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-eplain >= %{texlive_version}
#!BuildIgnore:  texlive-eplain
Prefix:         %{_bindir}

%description eplain-bin
Binary files of eplain

%package epspdf-bin
Version:        %{texlive_version}.%{texlive_release}.svn29050
Release:        26.29
Summary:        Binary files of epspdf
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-epspdf >= %{texlive_version}
#!BuildIgnore:  texlive-epspdf
Prefix:         %{_bindir}

%description epspdf-bin
Binary files of epspdf

%package epstopdf-bin
Version:        %{texlive_version}.%{texlive_release}.svn18336
Release:        26.29
Summary:        Binary files of epstopdf
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-epstopdf >= %{texlive_version}
#!BuildIgnore:  texlive-epstopdf
Prefix:         %{_bindir}

%description epstopdf-bin
Binary files of epstopdf

%package exceltex-bin
Version:        %{texlive_version}.%{texlive_release}.svn25860
Release:        26.29
Summary:        Binary files of exceltex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-exceltex >= %{texlive_version}
#!BuildIgnore:  texlive-exceltex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description exceltex-bin
Binary files of exceltex

%package fig4latex-bin
Version:        %{texlive_version}.%{texlive_release}.svn14752
Release:        26.29
Summary:        Binary files of fig4latex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-fig4latex >= %{texlive_version}
#!BuildIgnore:  texlive-fig4latex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-latexrecommended >= %{texlive_version}
Prefix:         %{_bindir}

%description fig4latex-bin
Binary files of fig4latex

%package findhyph-bin
Version:        %{texlive_version}.%{texlive_release}.svn14758
Release:        26.29
Summary:        Binary files of findhyph
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-findhyph >= %{texlive_version}
#!BuildIgnore:  texlive-findhyph
Prefix:         %{_bindir}

%description findhyph-bin
Binary files of findhyph

%package fontinst-bin
Version:        %{texlive_version}.%{texlive_release}.svn29741
Release:        26.29
Summary:        Binary files of fontinst
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-fontinst >= %{texlive_version}
#!BuildIgnore:  texlive-fontinst
Prefix:         %{_bindir}

%description fontinst-bin
Binary files of fontinst

%package fontools-bin
Version:        %{texlive_version}.%{texlive_release}.svn25997
Release:        26.29
Summary:        Binary files of fontools
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-fontools >= %{texlive_version}
#!BuildIgnore:  texlive-fontools
Prefix:         %{_bindir}

%description fontools-bin
Binary files of fontools

%package fontware-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of fontware
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-fontware >= %{texlive_version}
#!BuildIgnore:  texlive-fontware
Prefix:         %{_bindir}

%description fontware-bin
Binary files of fontware

%package fragmaster-bin
Version:        %{texlive_version}.%{texlive_release}.svn13663
Release:        26.29
Summary:        Binary files of fragmaster
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-fragmaster >= %{texlive_version}
#!BuildIgnore:  texlive-fragmaster
Prefix:         %{_bindir}

%description fragmaster-bin
Binary files of fragmaster

%package getmap-bin
Version:        %{texlive_version}.%{texlive_release}.svn34971
Release:        26.29
Summary:        Binary files of getmap
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-getmap >= %{texlive_version}
#!BuildIgnore:  texlive-getmap
Prefix:         %{_bindir}

%description getmap-bin
Binary files of getmap

%package glossaries-bin
Version:        %{texlive_version}.%{texlive_release}.svn37813
Release:        26.29
Summary:        Binary files of glossaries
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-glossaries >= %{texlive_version}
#!BuildIgnore:  texlive-glossaries
Prefix:         %{_bindir}

%description glossaries-bin
Binary files of glossaries

%package gsftopk-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of gsftopk
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-gsftopk >= %{texlive_version}
#!BuildIgnore:  texlive-gsftopk
Prefix:         %{_bindir}

%description gsftopk-bin
Binary files of gsftopk

%package jadetex-bin
Version:        %{texlive_version}.%{texlive_release}.svn3006
Release:        26.29
Summary:        Binary files of jadetex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Obsoletes:      texlive-bin-jadetex <= %{texlive_previous}
Requires(pre):  texlive-jadetex >= %{texlive_version}
#!BuildIgnore:  texlive-jadetex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description jadetex-bin
Binary files of jadetex

%package jfontmaps-bin
Version:        %{texlive_version}.%{texlive_release}.svn29848
Release:        26.29
Summary:        Binary files of jfontmaps
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-jfontmaps >= %{texlive_version}
#!BuildIgnore:  texlive-jfontmaps
Prefix:         %{_bindir}

%description jfontmaps-bin
Binary files of jfontmaps

%package kotex-utils-bin
Version:        %{texlive_version}.%{texlive_release}.svn32101
Release:        26.29
Summary:        Binary files of kotex-utils
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-kotex-utils >= %{texlive_version}
#!BuildIgnore:  texlive-kotex-utils
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description kotex-utils-bin
Binary files of kotex-utils

%package kpathsea-bin
Version:        %{texlive_version}.%{texlive_release}.svn37207
Release:        26.29
Summary:        Binary files of kpathsea
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):    %{name}-filesystem
Requires(pre):    /usr/bin/getent
Requires(pre):    /usr/sbin/groupadd
Requires(post):   %{name}-filesystem
Requires(post):   permissions
Requires(verify): %{name}-filesystem
Requires(verify): permissions
Requires(pre):  texlive-kpathsea >= %{texlive_version}
#!BuildIgnore:  texlive-kpathsea
Prefix:         %{_bindir}

%description kpathsea-bin
Binary files of kpathsea

%package lacheck-bin
Version:        %{texlive_version}.%{texlive_release}.svn37340
Release:        26.29
Summary:        Binary files of lacheck
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-lacheck >= %{texlive_version}
#!BuildIgnore:  texlive-lacheck
Prefix:         %{_bindir}

%description lacheck-bin
Binary files of lacheck

%package latex-bin-bin
Version:        %{texlive_version}.%{texlive_release}.svn14050
Release:        26.29
Summary:        Binary files of latex-bin
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Obsoletes:      texlive-bin-latex <= %{texlive_previous}
Requires(pre):  texlive-latex-bin >= %{texlive_version}
#!BuildIgnore:  texlive-latex-bin
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-latexrecommended >= %{texlive_version}
Prefix:         %{_bindir}

%description latex-bin-bin
Binary files of latex-bin

%package latex-git-log-bin
Version:        %{texlive_version}.%{texlive_release}.svn30983
Release:        26.29
Summary:        Binary files of latex-git-log
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-latex-git-log >= %{texlive_version}
#!BuildIgnore:  texlive-latex-git-log
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-latexrecommended >= %{texlive_version}
Prefix:         %{_bindir}

%description latex-git-log-bin
Binary files of latex-git-log

%package latex2man-bin
Version:        %{texlive_version}.%{texlive_release}.svn13663
Release:        26.29
Summary:        Binary files of latex2man
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-latex2man >= %{texlive_version}
#!BuildIgnore:  texlive-latex2man
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-latexrecommended >= %{texlive_version}
Prefix:         %{_bindir}

%description latex2man-bin
Binary files of latex2man

%package latexdiff-bin
Version:        %{texlive_version}.%{texlive_release}.svn16420
Release:        26.29
Summary:        Binary files of latexdiff
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-latexdiff >= %{texlive_version}
#!BuildIgnore:  texlive-latexdiff
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-latexrecommended >= %{texlive_version}
Prefix:         %{_bindir}

%description latexdiff-bin
Binary files of latexdiff

%package latexfileversion-bin
Version:        %{texlive_version}.%{texlive_release}.svn25012
Release:        26.29
Summary:        Binary files of latexfileversion
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-latexfileversion >= %{texlive_version}
#!BuildIgnore:  texlive-latexfileversion
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-latexrecommended >= %{texlive_version}
Prefix:         %{_bindir}

%description latexfileversion-bin
Binary files of latexfileversion

%package latexindent-bin
Version:        %{texlive_version}.%{texlive_release}.svn32150
Release:        26.29
Summary:        Binary files of latexindent
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-latexindent >= %{texlive_version}
#!BuildIgnore:  texlive-latexindent
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-latexrecommended >= %{texlive_version}
Prefix:         %{_bindir}

%description latexindent-bin
Binary files of latexindent

%package latexmk-bin
Version:        %{texlive_version}.%{texlive_release}.svn10937
Release:        26.29
Summary:        Binary files of latexmk
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-latexmk >= %{texlive_version}
#!BuildIgnore:  texlive-latexmk
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-latexrecommended >= %{texlive_version}
Prefix:         %{_bindir}

%description latexmk-bin
Binary files of latexmk

%package latexpand-bin
Version:        %{texlive_version}.%{texlive_release}.svn27025
Release:        26.29
Summary:        Binary files of latexpand
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-latexpand >= %{texlive_version}
#!BuildIgnore:  texlive-latexpand
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-latexrecommended >= %{texlive_version}
Prefix:         %{_bindir}

%description latexpand-bin
Binary files of latexpand

%package lcdftypetools-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of lcdftypetools
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
%if %{with lcdf_typetools}
Conflicts:      lcdf-typetools
%else
Requires:       lcdf-typetools
%endif
Requires(pre):  texlive-lcdftypetools >= %{texlive_version}
#!BuildIgnore:  texlive-lcdftypetools
Prefix:         %{_bindir}

%description lcdftypetools-bin
Binary files of lcdftypetools

%package lilyglyphs-bin
Version:        %{texlive_version}.%{texlive_release}.svn31696
Release:        26.29
Summary:        Binary files of lilyglyphs
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-lilyglyphs >= %{texlive_version}
#!BuildIgnore:  texlive-lilyglyphs
Prefix:         %{_bindir}

%description lilyglyphs-bin
Binary files of lilyglyphs

%package listbib-bin
Version:        %{texlive_version}.%{texlive_release}.svn26126
Release:        26.29
Summary:        Binary files of listbib
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-listbib >= %{texlive_version}
#!BuildIgnore:  texlive-listbib
Prefix:         %{_bindir}

%description listbib-bin
Binary files of listbib

%package listings-ext-bin
Version:        %{texlive_version}.%{texlive_release}.svn15093
Release:        26.29
Summary:        Binary files of listings-ext
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-listings-ext >= %{texlive_version}
#!BuildIgnore:  texlive-listings-ext
Prefix:         %{_bindir}

%description listings-ext-bin
Binary files of listings-ext

%package lollipop-bin
Version:        %{texlive_version}.%{texlive_release}.svn33658
Release:        26.29
Summary:        Binary files of lollipop
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-lollipop >= %{texlive_version}
#!BuildIgnore:  texlive-lollipop
Prefix:         %{_bindir}

%description lollipop-bin
Binary files of lollipop

%package ltxfileinfo-bin
Version:        %{texlive_version}.%{texlive_release}.svn29005
Release:        26.29
Summary:        Binary files of ltxfileinfo
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-ltxfileinfo >= %{texlive_version}
#!BuildIgnore:  texlive-ltxfileinfo
Prefix:         %{_bindir}

%description ltxfileinfo-bin
Binary files of ltxfileinfo

%package ltximg-bin
Version:        %{texlive_version}.%{texlive_release}.svn32346
Release:        26.29
Summary:        Binary files of ltximg
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-ltximg >= %{texlive_version}
#!BuildIgnore:  texlive-ltximg
Prefix:         %{_bindir}

%description ltximg-bin
Binary files of ltximg

%package lua2dox-bin
Version:        %{texlive_version}.%{texlive_release}.svn29053
Release:        26.29
Summary:        Binary files of lua2dox
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-lua2dox >= %{texlive_version}
#!BuildIgnore:  texlive-lua2dox
Prefix:         %{_bindir}

%description lua2dox-bin
Binary files of lua2dox

%package luaotfload-bin
Version:        %{texlive_version}.%{texlive_release}.svn34647
Release:        26.29
Summary:        Binary files of luaotfload
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-luaotfload >= %{texlive_version}
#!BuildIgnore:  texlive-luaotfload
Prefix:         %{_bindir}

%description luaotfload-bin
Binary files of luaotfload

%package luatex-bin
Version:        %{texlive_version}.%{texlive_release}.svn37340
Release:        26.29
Summary:        Binary files of luatex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-luatex >= %{texlive_version}
#!BuildIgnore:  texlive-luatex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-luatex >= %{texlive_version}
Prefix:         %{_bindir}

%description luatex-bin
Binary files of luatex

%package m-tx-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of m-tx
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-m-tx >= %{texlive_version}
#!BuildIgnore:  texlive-m-tx
Prefix:         %{_bindir}

%description m-tx-bin
Binary files of m-tx

%package make4ht-bin
Version:        %{texlive_version}.%{texlive_release}.svn37750
Release:        26.29
Summary:        Binary files of make4ht
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-make4ht >= %{texlive_version}
#!BuildIgnore:  texlive-make4ht
Prefix:         %{_bindir}

%description make4ht-bin
Binary files of make4ht

%package makeindex-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of makeindex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-makeindex >= %{texlive_version}
#!BuildIgnore:  texlive-makeindex
Prefix:         %{_bindir}

%description makeindex-bin
Binary files of makeindex

%package match_parens-bin
Version:        %{texlive_version}.%{texlive_release}.svn23500
Release:        26.29
Summary:        Binary files of match_parens
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-match_parens >= %{texlive_version}
#!BuildIgnore:  texlive-match_parens
Prefix:         %{_bindir}

%description match_parens-bin
Binary files of match_parens

%package mathspic-bin
Version:        %{texlive_version}.%{texlive_release}.svn23661
Release:        26.29
Summary:        Binary files of mathspic
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-mathspic >= %{texlive_version}
#!BuildIgnore:  texlive-mathspic
Prefix:         %{_bindir}

%description mathspic-bin
Binary files of mathspic

%package metafont-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of metafont
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-metafont >= %{texlive_version}
#!BuildIgnore:  texlive-metafont
Prefix:         %{_bindir}

%description metafont-bin
Binary files of metafont

%package metapost-bin
Version:        %{texlive_version}.%{texlive_release}.svn37340
Release:        26.29
Summary:        Binary files of metapost
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Obsoletes:      texlive-bin-metapost <= %{texlive_previous}
Requires(pre):  texlive-metapost >= %{texlive_version}
#!BuildIgnore:  texlive-metapost
Prefix:         %{_bindir}

%description metapost-bin
Binary files of metapost

%package mex-bin
Version:        %{texlive_version}.%{texlive_release}.svn3006
Release:        26.29
Summary:        Binary files of mex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-mex >= %{texlive_version}
#!BuildIgnore:  texlive-mex
Prefix:         %{_bindir}

%description mex-bin
Binary files of mex

%package mf2pt1-bin
Version:        %{texlive_version}.%{texlive_release}.svn23406
Release:        26.29
Summary:        Binary files of mf2pt1
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-mf2pt1 >= %{texlive_version}
#!BuildIgnore:  texlive-mf2pt1
Prefix:         %{_bindir}

%description mf2pt1-bin
Binary files of mf2pt1

%package mfware-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of mfware
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-mfware >= %{texlive_version}
#!BuildIgnore:  texlive-mfware
Prefix:         %{_bindir}

%description mfware-bin
Binary files of mfware

%package mkgrkindex-bin
Version:        %{texlive_version}.%{texlive_release}.svn14428
Release:        26.29
Summary:        Binary files of mkgrkindex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-mkgrkindex >= %{texlive_version}
#!BuildIgnore:  texlive-mkgrkindex
Prefix:         %{_bindir}

%description mkgrkindex-bin
Binary files of mkgrkindex

%package mkjobtexmf-bin
Version:        %{texlive_version}.%{texlive_release}.svn8457
Release:        26.29
Summary:        Binary files of mkjobtexmf
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-mkjobtexmf >= %{texlive_version}
#!BuildIgnore:  texlive-mkjobtexmf
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description mkjobtexmf-bin
Binary files of mkjobtexmf

%package mkpic-bin
Version:        %{texlive_version}.%{texlive_release}.svn33688
Release:        26.29
Summary:        Binary files of mkpic
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-mkpic >= %{texlive_version}
#!BuildIgnore:  texlive-mkpic
Prefix:         %{_bindir}

%description mkpic-bin
Binary files of mkpic

%package mltex-bin
Version:        %{texlive_version}.%{texlive_release}.svn3006
Release:        26.29
Summary:        Binary files of mltex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-mltex >= %{texlive_version}
#!BuildIgnore:  texlive-mltex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description mltex-bin
Binary files of mltex

%package mptopdf-bin
Version:        %{texlive_version}.%{texlive_release}.svn18674
Release:        26.29
Summary:        Binary files of mptopdf
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-mptopdf >= %{texlive_version}
#!BuildIgnore:  texlive-mptopdf
Prefix:         %{_bindir}

%description mptopdf-bin
Binary files of mptopdf

%package multibibliography-bin
Version:        %{texlive_version}.%{texlive_release}.svn30534
Release:        26.29
Summary:        Binary files of multibibliography
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-multibibliography >= %{texlive_version}
#!BuildIgnore:  texlive-multibibliography
Prefix:         %{_bindir}

%description multibibliography-bin
Binary files of multibibliography

%package musixtex-bin
Version:        %{texlive_version}.%{texlive_release}.svn37026
Release:        26.29
Summary:        Binary files of musixtex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Obsoletes:      texlive-bin-musictex <= %{texlive_previous}
Requires:       texlive-m-tx-bin >= %{texlive_version}
Requires:       texlive-pmx-bin >= %{texlive_version}
Requires(pre):  texlive-musixtex >= %{texlive_version}
#!BuildIgnore:  texlive-musixtex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description musixtex-bin
Binary files of musixtex

%package musixtnt-bin
Version:        %{texlive_version}.%{texlive_release}.svn37035
Release:        26.29
Summary:        Binary files of musixtnt
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-musixtnt >= %{texlive_version}
#!BuildIgnore:  texlive-musixtnt
Prefix:         %{_bindir}

%description musixtnt-bin
Binary files of musixtnt

%package omegaware-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of omegaware
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Obsoletes:      texlive-bin-omega <= %{texlive_previous}
Requires:       texlive-uptex-bin >= %{texlive_version}
Requires(pre):  texlive-omegaware >= %{texlive_version}
#!BuildIgnore:  texlive-omegaware
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-omega >= %{texlive_version}
Prefix:         %{_bindir}

%description omegaware-bin
Binary files of omegaware

%package patgen-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of patgen
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-patgen >= %{texlive_version}
#!BuildIgnore:  texlive-patgen
Prefix:         %{_bindir}

%description patgen-bin
Binary files of patgen

%package pax-bin
Version:        %{texlive_version}.%{texlive_release}.svn10843
Release:        26.29
Summary:        Binary files of pax
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-pax >= %{texlive_version}
#!BuildIgnore:  texlive-pax
Prefix:         %{_bindir}

%description pax-bin
Binary files of pax

%package pdfbook2-bin
Version:        %{texlive_version}.%{texlive_release}.svn37537
Release:        26.29
Summary:        Binary files of pdfbook2
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-pdfbook2 >= %{texlive_version}
#!BuildIgnore:  texlive-pdfbook2
Prefix:         %{_bindir}

%description pdfbook2-bin
Binary files of pdfbook2

%package pdfcrop-bin
Version:        %{texlive_version}.%{texlive_release}.svn14387
Release:        26.29
Summary:        Binary files of pdfcrop
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-pdfcrop >= %{texlive_version}
#!BuildIgnore:  texlive-pdfcrop
Prefix:         %{_bindir}

%description pdfcrop-bin
Binary files of pdfcrop

%package pdfjam-bin
Version:        %{texlive_version}.%{texlive_release}.svn17868
Release:        26.29
Summary:        Binary files of pdfjam
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-pdfjam >= %{texlive_version}
#!BuildIgnore:  texlive-pdfjam
Prefix:         %{_bindir}

%description pdfjam-bin
Binary files of pdfjam

%package pdftex-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of pdftex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-pdftex >= %{texlive_version}
#!BuildIgnore:  texlive-pdftex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description pdftex-bin
Binary files of pdftex

%package pdftools-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of pdftools
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-pdftools >= %{texlive_version}
#!BuildIgnore:  texlive-pdftools
Prefix:         %{_bindir}

%description pdftools-bin
Binary files of pdftools

%package pedigree-perl-bin
Version:        %{texlive_version}.%{texlive_release}.svn25962
Release:        26.29
Summary:        Binary files of pedigree-perl
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-pedigree-perl >= %{texlive_version}
#!BuildIgnore:  texlive-pedigree-perl
Prefix:         %{_bindir}

%description pedigree-perl-bin
Binary files of pedigree-perl

%package perltex-bin
Version:        %{texlive_version}.%{texlive_release}.svn16181
Release:        26.29
Summary:        Binary files of perltex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-perltex >= %{texlive_version}
#!BuildIgnore:  texlive-perltex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description perltex-bin
Binary files of perltex

%package pfarrei-bin
Version:        %{texlive_version}.%{texlive_release}.svn29348
Release:        26.29
Summary:        Binary files of pfarrei
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-pfarrei >= %{texlive_version}
#!BuildIgnore:  texlive-pfarrei
Prefix:         %{_bindir}

%description pfarrei-bin
Binary files of pfarrei

%package pkfix-helper-bin
Version:        %{texlive_version}.%{texlive_release}.svn13663
Release:        26.29
Summary:        Binary files of pkfix-helper
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-pkfix-helper >= %{texlive_version}
#!BuildIgnore:  texlive-pkfix-helper
Prefix:         %{_bindir}

%description pkfix-helper-bin
Binary files of pkfix-helper

%package pkfix-bin
Version:        %{texlive_version}.%{texlive_release}.svn13364
Release:        26.29
Summary:        Binary files of pkfix
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-pkfix >= %{texlive_version}
#!BuildIgnore:  texlive-pkfix
Prefix:         %{_bindir}

%description pkfix-bin
Binary files of pkfix

%package pmx-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of pmx
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-pmx >= %{texlive_version}
#!BuildIgnore:  texlive-pmx
Prefix:         %{_bindir}

%description pmx-bin
Binary files of pmx

%package pmxchords-bin
Version:        %{texlive_version}.%{texlive_release}.svn32405
Release:        26.29
Summary:        Binary files of pmxchords
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-pmxchords >= %{texlive_version}
#!BuildIgnore:  texlive-pmxchords
Prefix:         %{_bindir}

%description pmxchords-bin
Binary files of pmxchords

%package ps2pk-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of ps2pk
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Obsoletes:      texlive-texlive-ps2pkm-bin <= 2014
Requires(pre):  texlive-ps2pk >= %{texlive_version}
#!BuildIgnore:  texlive-ps2pk
Prefix:         %{_bindir}

%description ps2pk-bin
Binary files of ps2pk

%package pst-pdf-bin
Version:        %{texlive_version}.%{texlive_release}.svn7838
Release:        26.29
Summary:        Binary files of pst-pdf
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-pst-pdf >= %{texlive_version}
#!BuildIgnore:  texlive-pst-pdf
Prefix:         %{_bindir}

%description pst-pdf-bin
Binary files of pst-pdf

%package pst2pdf-bin
Version:        %{texlive_version}.%{texlive_release}.svn29333
Release:        26.29
Summary:        Binary files of pst2pdf
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-pst2pdf >= %{texlive_version}
#!BuildIgnore:  texlive-pst2pdf
Prefix:         %{_bindir}

%description pst2pdf-bin
Binary files of pst2pdf

%package pstools-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of pstools
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-pstools >= %{texlive_version}
#!BuildIgnore:  texlive-pstools
Prefix:         %{_bindir}

%description pstools-bin
Binary files of pstools

%package ptex-bin
Version:        %{texlive_version}.%{texlive_release}.svn37340
Release:        26.29
Summary:        Binary files of ptex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-ptex >= %{texlive_version}
#!BuildIgnore:  texlive-ptex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description ptex-bin
Binary files of ptex

%package ptex2pdf-bin
Version:        %{texlive_version}.%{texlive_release}.svn29335
Release:        26.29
Summary:        Binary files of ptex2pdf
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-ptex2pdf >= %{texlive_version}
#!BuildIgnore:  texlive-ptex2pdf
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description ptex2pdf-bin
Binary files of ptex2pdf

%package purifyeps-bin
Version:        %{texlive_version}.%{texlive_release}.svn13663
Release:        26.29
Summary:        Binary files of purifyeps
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-purifyeps >= %{texlive_version}
#!BuildIgnore:  texlive-purifyeps
Prefix:         %{_bindir}

%description purifyeps-bin
Binary files of purifyeps

%package pygmentex-bin
Version:        %{texlive_version}.%{texlive_release}.svn34996
Release:        26.29
Summary:        Binary files of pygmentex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-pygmentex >= %{texlive_version}
#!BuildIgnore:  texlive-pygmentex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description pygmentex-bin
Binary files of pygmentex

%package pythontex-bin
Version:        %{texlive_version}.%{texlive_release}.svn31638
Release:        26.29
Summary:        Binary files of pythontex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-pythontex >= %{texlive_version}
#!BuildIgnore:  texlive-pythontex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description pythontex-bin
Binary files of pythontex

%package rubik-bin
Version:        %{texlive_version}.%{texlive_release}.svn32919
Release:        26.29
Summary:        Binary files of rubik
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-rubik >= %{texlive_version}
#!BuildIgnore:  texlive-rubik
Prefix:         %{_bindir}

%description rubik-bin
Binary files of rubik

%package seetexk-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of seetexk
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-seetexk >= %{texlive_version}
#!BuildIgnore:  texlive-seetexk
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description seetexk-bin
Binary files of seetexk

%package splitindex-bin
Version:        %{texlive_version}.%{texlive_release}.svn29688
Release:        26.29
Summary:        Binary files of splitindex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-splitindex >= %{texlive_version}
#!BuildIgnore:  texlive-splitindex
Prefix:         %{_bindir}

%description splitindex-bin
Binary files of splitindex

%package sty2dtx-bin
Version:        %{texlive_version}.%{texlive_release}.svn21215
Release:        26.29
Summary:        Binary files of sty2dtx
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-sty2dtx >= %{texlive_version}
#!BuildIgnore:  texlive-sty2dtx
Prefix:         %{_bindir}

%description sty2dtx-bin
Binary files of sty2dtx

%package svn-multi-bin
Version:        %{texlive_version}.%{texlive_release}.svn13663
Release:        26.29
Summary:        Binary files of svn-multi
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-svn-multi >= %{texlive_version}
#!BuildIgnore:  texlive-svn-multi
Prefix:         %{_bindir}

%description svn-multi-bin
Binary files of svn-multi

%package synctex-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of synctex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-synctex >= %{texlive_version}
#!BuildIgnore:  texlive-synctex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description synctex-bin
Binary files of synctex

%package tetex-bin
Version:        %{texlive_version}.%{texlive_release}.svn36770
Release:        26.29
Summary:        Binary files of tetex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-tetex >= %{texlive_version}
#!BuildIgnore:  texlive-tetex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description tetex-bin
Binary files of tetex

%package tex-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of tex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-tex >= %{texlive_version}
#!BuildIgnore:  texlive-tex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description tex-bin
Binary files of tex

%package tex4ebook-bin
Version:        %{texlive_version}.%{texlive_release}.svn37771
Release:        26.29
Summary:        Binary files of tex4ebook
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-tex4ebook >= %{texlive_version}
#!BuildIgnore:  texlive-tex4ebook
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description tex4ebook-bin
Binary files of tex4ebook

%package tex4ht-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of tex4ht
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Obsoletes:      texlive-bin-tex4ht <= %{texlive_previous}
Conflicts:      ht
Requires(pre):  texlive-tex4ht >= %{texlive_version}
#!BuildIgnore:  texlive-tex4ht
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description tex4ht-bin
Binary files of tex4ht

%package texconfig-bin
Version:        %{texlive_version}.%{texlive_release}.svn29741
Release:        26.29
Summary:        Binary files of texconfig
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-texconfig >= %{texlive_version}
#!BuildIgnore:  texlive-texconfig
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description texconfig-bin
Binary files of texconfig

%package texcount-bin
Version:        %{texlive_version}.%{texlive_release}.svn13013
Release:        26.29
Summary:        Binary files of texcount
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-texcount >= %{texlive_version}
#!BuildIgnore:  texlive-texcount
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description texcount-bin
Binary files of texcount

%package texdef-bin
Version:        %{texlive_version}.%{texlive_release}.svn21802
Release:        26.29
Summary:        Binary files of texdef
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-texdef >= %{texlive_version}
#!BuildIgnore:  texlive-texdef
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description texdef-bin
Binary files of texdef

%package texdiff-bin
Version:        %{texlive_version}.%{texlive_release}.svn15506
Release:        26.29
Summary:        Binary files of texdiff
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-texdiff >= %{texlive_version}
#!BuildIgnore:  texlive-texdiff
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description texdiff-bin
Binary files of texdiff

%package texdirflatten-bin
Version:        %{texlive_version}.%{texlive_release}.svn12782
Release:        26.29
Summary:        Binary files of texdirflatten
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-texdirflatten >= %{texlive_version}
#!BuildIgnore:  texlive-texdirflatten
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description texdirflatten-bin
Binary files of texdirflatten

%package texdoc-bin
Version:        %{texlive_version}.%{texlive_release}.svn29741
Release:        26.29
Summary:        Binary files of texdoc
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-texdoc >= %{texlive_version}
#!BuildIgnore:  texlive-texdoc
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description texdoc-bin
Binary files of texdoc

%package texfot-bin
Version:        %{texlive_version}.%{texlive_release}.svn33155
Release:        26.29
Summary:        Binary files of texfot
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-texfot >= %{texlive_version}
#!BuildIgnore:  texlive-texfot
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description texfot-bin
Binary files of texfot

%package texliveonfly-bin
Version:        %{texlive_version}.%{texlive_release}.svn24062
Release:        26.29
Summary:        Binary files of texliveonfly
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-texliveonfly >= %{texlive_version}
#!BuildIgnore:  texlive-texliveonfly
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description texliveonfly-bin
Binary files of texliveonfly

%package texloganalyser-bin
Version:        %{texlive_version}.%{texlive_release}.svn13663
Release:        26.29
Summary:        Binary files of texloganalyser
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-texloganalyser >= %{texlive_version}
#!BuildIgnore:  texlive-texloganalyser
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description texloganalyser-bin
Binary files of texloganalyser

%package texsis-bin
Version:        %{texlive_version}.%{texlive_release}.svn3006
Release:        26.29
Summary:        Binary files of texsis
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-texsis >= %{texlive_version}
#!BuildIgnore:  texlive-texsis
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description texsis-bin
Binary files of texsis

%package texware-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of texware
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-texware >= %{texlive_version}
#!BuildIgnore:  texlive-texware
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description texware-bin
Binary files of texware

%package thumbpdf-bin
Version:        %{texlive_version}.%{texlive_release}.svn6898
Release:        26.29
Summary:        Binary files of thumbpdf
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-thumbpdf >= %{texlive_version}
#!BuildIgnore:  texlive-thumbpdf
Prefix:         %{_bindir}

%description thumbpdf-bin
Binary files of thumbpdf

%package tie-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of tie
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-tie >= %{texlive_version}
#!BuildIgnore:  texlive-tie
Prefix:         %{_bindir}

%description tie-bin
Binary files of tie

%package tpic2pdftex-bin
Version:        %{texlive_version}.%{texlive_release}.svn29741
Release:        26.29
Summary:        Binary files of tpic2pdftex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-tpic2pdftex >= %{texlive_version}
#!BuildIgnore:  texlive-tpic2pdftex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description tpic2pdftex-bin
Binary files of tpic2pdftex

%package ttfutils-bin
Version:        %{texlive_version}.%{texlive_release}.svn37100
Release:        26.29
Summary:        Binary files of ttfutils
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-ttfutils >= %{texlive_version}
#!BuildIgnore:  texlive-ttfutils
Prefix:         %{_bindir}

%description ttfutils-bin
Binary files of ttfutils

%package typeoutfileinfo-bin
Version:        %{texlive_version}.%{texlive_release}.svn25648
Release:        26.29
Summary:        Binary files of typeoutfileinfo
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-typeoutfileinfo >= %{texlive_version}
#!BuildIgnore:  texlive-typeoutfileinfo
Prefix:         %{_bindir}

%description typeoutfileinfo-bin
Binary files of typeoutfileinfo

%package ulqda-bin
Version:        %{texlive_version}.%{texlive_release}.svn13663
Release:        26.29
Summary:        Binary files of ulqda
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-ulqda >= %{texlive_version}
#!BuildIgnore:  texlive-ulqda
Prefix:         %{_bindir}

%description ulqda-bin
Binary files of ulqda

%package uptex-bin
Version:        %{texlive_version}.%{texlive_release}.svn37340
Release:        26.29
Summary:        Binary files of uptex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-uptex >= %{texlive_version}
#!BuildIgnore:  texlive-uptex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-basic >= %{texlive_version}
Prefix:         %{_bindir}

%description uptex-bin
Binary files of uptex

%package urlbst-bin
Version:        %{texlive_version}.%{texlive_release}.svn23262
Release:        26.29
Summary:        Binary files of urlbst
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-urlbst >= %{texlive_version}
#!BuildIgnore:  texlive-urlbst
Prefix:         %{_bindir}

%description urlbst-bin
Binary files of urlbst

%package vlna-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of vlna
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-vlna >= %{texlive_version}
#!BuildIgnore:  texlive-vlna
Prefix:         %{_bindir}

%description vlna-bin
Binary files of vlna

%package vpe-bin
Version:        %{texlive_version}.%{texlive_release}.svn6897
Release:        26.29
Summary:        Binary files of vpe
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-vpe >= %{texlive_version}
#!BuildIgnore:  texlive-vpe
Prefix:         %{_bindir}

%description vpe-bin
Binary files of vpe

%package web-bin
Version:        %{texlive_version}.%{texlive_release}.svn36790
Release:        26.29
Summary:        Binary files of web
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-web >= %{texlive_version}
#!BuildIgnore:  texlive-web
Prefix:         %{_bindir}

%description web-bin
Binary files of web

%package xdvi-bin
Version:        %{texlive_version}.%{texlive_release}.svn37100
Release:        26.29
Summary:        Binary files of xdvi
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-xdvi >= %{texlive_version}
#!BuildIgnore:  texlive-xdvi
Prefix:         %{_bindir}

%description xdvi-bin
Binary files of xdvi

%package xetex-bin
Version:        %{texlive_version}.%{texlive_release}.svn37261
Release:        26.29
Summary:        Binary files of xetex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Obsoletes:      texlive-bin-xetex <= %{texlive_previous}
Requires(pre):  texlive-xetex >= %{texlive_version}
#!BuildIgnore:  texlive-xetex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-xetex >= %{texlive_version}
Prefix:         %{_bindir}

%description xetex-bin
Binary files of xetex

%package xmltex-bin
Version:        %{texlive_version}.%{texlive_release}.svn3006
Release:        26.29
Summary:        Binary files of xmltex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Obsoletes:      texlive-bin-xmltex <= %{texlive_previous}
Requires(pre):  texlive-xmltex >= %{texlive_version}
#!BuildIgnore:  texlive-xmltex
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-htmlxml >= %{texlive_version}
Prefix:         %{_bindir}

%description xmltex-bin
Binary files of xmltex

%package yplan-bin
Version:        %{texlive_version}.%{texlive_release}.svn34398
Release:        26.29
Summary:        Binary files of yplan
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://www.tug.org/texlive/
Requires(pre):  texlive-yplan >= %{texlive_version}
#!BuildIgnore:  texlive-yplan
Prefix:         %{_bindir}

%description yplan-bin
Binary files of yplan

%package -n libkpathsea6
Version:        6.2.1
Release:        26.29
Summary:        Path searching library for TeX-related files
License:        LGPL-2.1+
Group:          System/Libraries
Url:            http://www.tug.org/texlive/
Prefix:         %{_libdir}

%description -n libkpathsea6
Kpathsea is a library and utility programs which provide path
searching facilities for TeX file types, including the self-
locating feature required for movable installations, layered on
top of a general search mechanism. It is not distributed
separately, but rather is released and maintained as part of
the TeX-live sources.

%package -n %{name}-kpathsea-devel
Version:        6.2.1
Release:        26.29
Summary:        Path searching library for TeX-related files
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            http://www.tug.org/texlive/
Requires:       libkpathsea6 = 6.2.1

%description -n %{name}-kpathsea-devel
Kpathsea is a library and utility programs which provide path
searching facilities for TeX file types, including the self-
locating feature required for movable installations, layered on
top of a general search mechanism. It is not distributed
separately, but rather is released and maintained as part of
the TeX-live sources.

%package -n libptexenc1
Version:        1.3.3
Release:        26.29
Summary:        Libraries of Kanji code convert library for pTeX
License:        BSD-3-Clause
Group:          System/Libraries
Url:            http://www.tug.org/texlive/
Prefix:         %{_libdir}

%description -n libptexenc1
The ptexenc is a useful library for Japanese pTeX
(which stands for publishing TeX, and is an extension of
TeX by ASCII Co.) and its surrounding tools.

%package -n %{name}-ptexenc-devel
Version:        1.3.3
Release:        26.29
Summary:        Libraries of Kanji code convert library for pTeX
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Url:            http://www.tug.org/texlive/
Requires:       libptexenc1 = 1.3.3

%description -n %{name}-ptexenc-devel
This package includes the ptexenc development files.
The ptexenc is a useful library for Japanese pTeX
(which stands for publishing TeX, and is an extension of
TeX by ASCII Co.) and its surrounding tools.

%package -n libsynctex1
Version:        1.17
Release:        26.29
Summary:        Libraries of The Synchronization TeXnology
License:        MIT
Group:          System/Libraries
Url:            http://www.tug.org/texlive/
Prefix:         %{_libdir}

%description -n libsynctex1
The Synchronization TeXnology by Jérôme Laurens is a new feature
of recent TeX engines.  It allows to synchronize between input
and output, which means to navigate from the source document to
the typeset material and vice versa.

%package -n %{name}-synctex-devel
Version:        1.17
Release:        26.29
Summary:        Libraries of The Synchronization TeXnology
License:        MIT
Group:          Development/Libraries/C and C++
Url:            http://www.tug.org/texlive/
Requires:       libsynctex1 = 1.17

%description -n %{name}-synctex-devel
This package includes the synctex development files.
The Synchronization TeXnology by Jérôme Laurens is a new feature
of recent TeX engines.  It allows to synchronize between input
and output, which means to navigate from the source document to
the typeset material and vice versa.

%package -n libtexlua52-5
Version:        5.2.4
Release:        26.29
Summary:        Libraries of an extended version of pdfTeX using Lua
License:        MIT
Group:          System/Libraries
Url:            http://www.tug.org/texlive/
Prefix:         %{_libdir}

%description -n libtexlua52-5
LuaTeX is an extended version of pdfTeX using Lua as an
embedded scripting language

%package -n %{name}-texlua-devel
Version:        5.2.4
Release:        26.29
Summary:        Libraries of an extended version of pdfTeX using Lua
License:        MIT
Group:          Development/Libraries/C and C++
Url:            http://www.tug.org/texlive/
Requires:       libtexlua52-5 = 5.2.4

%description -n %{name}-texlua-devel
This package includes the luatex development files.
LuaTeX is an extended version of pdfTeX using Lua as an
embedded scripting language

%if %{with LuaJIT}
%package -n libtexluajit2
Version:        2.0.3
Release:        26.29
Summary:        Libraries of Just-In-Time compiler for Lua
License:        MIT
Group:          System/Libraries
Url:            http://www.tug.org/texlive/
Prefix:         %{_libdir}

%description -n libtexluajit2
LuaJIT is a Just-In-Time (JIT) compiler for the Lua programming language

%package -n %{name}-texluajit-devel
Version:        2.0.3
Release:        26.29
Summary:        Libraries of Just-In-Time compiler for Lua
License:        MIT
Group:          Development/Libraries/C and C++
Url:            http://www.tug.org/texlive/
Requires:       libtexlua52-5 = 5.2.4

%description -n %{name}-texluajit-devel
This package includes the LuaJIT development files.
LuaJIT is a Just-In-Time (JIT) compiler for the Lua programming language
%endif

%package -n %{name}-bin-devel
Version:        %{texlive_version}.%{texlive_release}
Release:        26.29
Summary:        Basic development packages for TeXLive
License:        LGPL-2.1+ and BSD-3-Clause and SUSE-TeX
Group:          Development/Languages/Other
Url:            http://www.tug.org/texlive/
Requires:       libkpathsea6 = 6.2.1
Requires:       libptexenc1 = 1.3.3
Requires:       libsynctex1 = 1.17
Requires:       libtexlua52-5 = 5.2.4
%if %{with LuaJIT}
Requires:       libtexluajit2 = 2.0.3
%endif
Requires:       texlive-cweb-bin >= %{texlive_version}
Requires:       texlive-web-bin >= %{texlive_version}

%description -n %{name}-bin-devel
This package will cause the installation of several
development packages for TeXLive.

%if %{with buildbiber}
%package -n perl-biber
Version:        %{texlive_version}.%{texlive_release}.svn30357
Release:        26.29
Summary:        Library files of Biber a BibTeX replacement
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://biblatex-biber.sourceforge.net/
Recommends:     perl(Readonly::XS)
Requires:       perl(Business::ISBN)
Requires:       perl(Business::ISMN)
Requires:       perl(Business::ISSN)
Requires:       perl(Data::Compare)
Requires:       perl(Data::Dump)
Requires:       perl(Date::Simple)
Requires:       perl(Encode::EUCJPASCII)
Requires:       perl(Encode::HanExtra)
Requires:       perl(Encode::JIS2K)
Requires:       perl(File::Slurp)
Requires:       perl(IPC::Cmd)
Requires:       perl(IPC::Run3)
Requires:       perl(LWP::Protocol::https)
Requires:       perl(LWP::Simple)
Requires:       perl(List::AllUtils)
Requires:       perl(List::MoreUtils)
Requires:       perl(Log::Log4perl)
Requires:       perl(Regexp::Common)
Requires:       perl(Text::BibTeX)
Requires:       perl(Text::Roman)
Requires:       perl(URI)
Requires:       perl(Unicode::Collate)
Requires:       perl(Unicode::GCString)
Requires:       perl(XML::LibXML::Simple)
Requires:       perl(XML::LibXSLT)
Requires:       perl(XML::Writer)
Requires:       perl(autovivification)
Prefix:         %{_bindir}
BuildArch:      noarch

%description -n perl-biber
Perl library files of Biber a BibTeX replacement for users of BibLaTeX.
This package is required by the package texlive-biber-bin.
%endif

%prep
    OS=%{_target_os}
    CPU=%{_target_cpu}
%ifarch ia64
    RPM_OPT_FLAGS=$(echo "${RPM_OPT_FLAGS}"|sed -r 's/-O[0-9]?/-O1/g')
%endif
%ifarch %arm
    RPM_OPT_FLAGS=${RPM_OPT_FLAGS/-mthumb/-mthumb-interwork -marm}
%endif
    CC=gcc
    CXX=g++
    if grep -q _DEFAULT_SOURCE /usr/include/features.h ; then
	XCFLAGS="$RPM_OPT_FLAGS -D_POSIX_C_SOURCE=200803L -D_XOPEN_SOURCE=600 -D_DEFAULT_SOURCE"
    else
	XCFLAGS="$RPM_OPT_FLAGS -D_POSIX_C_SOURCE=200803L -D_XOPEN_SOURCE=600 -D_BSD_SOURCE"
    fi
    XCXXFLAGS="$XCFLAGS"
    cflags ()
    {
	local flag=$1; shift || return
	local cvar=$1; shift || return
	local xvar=$1; shift || true
	if test -z "${flag}" ; then
	    return
	fi
	case "$flag" in
	-Wl,*)
	    if test -z "${cvar}" ; then
		return
	    fi
	    case "${!cvar}" in
	    *${flag}*) return
	    esac
	    if echo 'int main () { return 0; }' | ${CC:-gcc} -Werror $flag -o /dev/null -xc - ; then
		eval $cvar=\${$cvar:+\$$cvar\ }$flag
	    fi
	    ;;
	*)
	    if test -z "${cvar}" ; then
		return
	    fi
	    case "${!cvar}" in
	    *${flag}*) ;;
	    *)	if ${CC:-gcc} -Werror $flag -S -o /dev/null -xc /dev/null ; then
		    eval $cvar=\${$cvar:+\$$cvar\ }$flag
		fi
	    esac
	    if test -z "${xvar}" ; then
		return
	    fi
	    case "${!xvar}" in
	    *${flag}*) ;;
	    *)	if ${CXX:-g++} -Werror $flag -S -o /dev/null -xc++ /dev/null ; then
		    eval $xvar=\${$xvar:+\$$xvar\ }$flag
		fi
	    esac
	esac > /dev/null 2>&1
    }
    cflags -std=gnu99			XCFLAGS
    cflags -fno-const-strings		XCFLAGS XCXXFLAGS
    cflags -fno-strict-aliasing		XCFLAGS XCXXFLAGS
    cflags -fPIC			XCFLAGS XCXXFLAGS
    cflags -Wno-write-strings		XCFLAGS XCXXFLAGS
    cflags -Wno-char-subscripts		XCFLAGS XCXXFLAGS
    cflags -Wno-unused			XCFLAGS XCXXFLAGS
    cflags -Wno-uninitialized		XCFLAGS XCXXFLAGS
    cflags -Wno-return-type		XCFLAGS XCXXFLAGS
    cflags -Wno-parentheses		XCFLAGS XCXXFLAGS
    cflags -Wno-sign-compare		XCFLAGS XCXXFLAGS
    cflags -Wno-unprototyped-calls	XCFLAGS
    cflags -pipe			XCFLAGS XCXXFLAGS
    cflags -Wl,-O2			XLDFLAGS
    cflags -Wl,--as-needed		XLDFLAGS
    cflags -Wl,--hash-size=8599		XLDFLAGS
    cflags -Wl,-warn-common		XLDFLAGS
    cflags -Wl,-Bsymbolic-functions	XLDFLAGS
    HOST=%{_target_cpu}-suse-%{_host_os}
    BUILD=%{_target_cpu}-suse-%{_build_os}
    BINARY=${CPU}-${OS}
    VENDOR="%{vendor}"
    VENDOR="${VENDOR%%%%,*}"

    # Generate the Options file
    exec 6>&1
    exec 1>|%{options}

    # On error clear
    trap 'rm -vf %{options}' ERR

    # Disable MALLOC_PERTURB_
    # echo unset MALLOC_PERTURB_

    # System wide configuration
    echo CPU=\"$CPU\"
    echo BINARY=\"${BINARY%%-gnu*}\"
    echo XCFLAGS=\"$XCFLAGS\"
    echo XCXXFLAGS=\"$XCXXFLAGS\"
    echo XLDFLAGS=\"$XLDFLAGS\"
    echo HOST=\"${HOST%%-gnu*}\"
    echo BUILD=\"${BUILD%%-gnu*}\"

    echo export XCFLAGS XCXXFLAGS XLDFLAGS HOST BUILD BINARY

    # Do not include e.g. from manual build
    echo unset TEXINPUTS TEXMF HOME

    # Use a well defined multi byte locale
    echo unset ${!LC_*}
    echo LANG=POSIX
    echo LC_CTYPE=en_US.UTF-8
    echo export LANG LC_CTYPE

    # Environment for configuration
    echo CONFIG_SHELL=/bin/bash
    echo CC=\"$CC\"
    echo CXX=\"$CXX\"
    echo CFLAGS=\"$XCFLAGS\"
    echo CXXFLAGS=\"$XCXXFLAGS\"
    echo LDFLAGS=\"-Wl,-warn-common $XLDFLAGS\"
    echo VENDOR=\"${VENDOR}\"
    echo ARCH_LIB=%{_lib}
    echo export CC CXX CFLAGS CXXFLAGS LDFLAGS VENDOR PATH CONFIG_SHELL ARCH_LIB LANG

    # Do not run TeX engine in fmtutil with batchmode
    echo batchmode=no
    echo export batchmode
%ifnarch hppa
    echo ulimit -s unlimited
%else
    # This is the maximum on hppa
    echo ulimit -s 81920
%endif
    exec 1>&6-

%setup -c -q -n texlive -T

    tar --use-compress-program=xz --strip-components=1 -xf %{S:0}
%if %{with buildbiber}
    pushd ../	
	tar --use-compress-program=xz -xf %{S:3}
    popd
%endif

%patch1  -p0 -b .configure
%patch2  -p0 -b .xdvizilla
%patch3  -p0 -b .arraysubs
%patch5  -p0 -b .texdoc
%patch6  -p0 -b .dviutils
%patch7  -p0 -b .xdvik
%if %{with psutils}
%patch8  -p0 -b .psutils
%endif
%patch10 -p0 -b .poppler
%patch11 -p0 -b .lacheck
%patch12 -p0 -b .warns
%patch13 -p0 -b .x11r7
%patch14 -p0 -b .maxpath
%patch15 -p0 -b .overflow
%patch17 -p0 -b .64
%patch18 -p0 -b .a2p
%patch19 -p0 -b .dvipng
%patch20 -p0 -b .missed
%patch0  -p0 -b .p0
%if %{with buildbiber}
pushd ../biblatex-biber-*
/usr/bin/chmod -Rf a+rX,u+w,g-w,o-w .
%patch42 -p0 -b .en
%if 0%{perl_versnum} >= 5200
%patch43 -p0 -b .522
%else
%patch47 -p0 -b .518
%endif
%patch44 -p0 -b .noica
%patch45 -p0 -b .pun
%patch46 -p0 -b .bcf
rm -vf bin/biber.noica
popd
%endif

    # Correct FHS paths
    paths=$(find -name cnf-to-paths.awk)
    test -n "$paths" || exit 1
    cp -vf %{S:4} $paths

%build
    # Extend the options file
    echo "world=${PWD}/world" >> %{options}
    echo "prefix=${PWD}/prefix" >> %{options}
    echo "texmfcnf=${PWD}/texk/kpathsea" >> %{options}

    # Read the options file
    . %{options}

    # Sanity check for system icu libraries and headers
    # Remark: official libicu is _not_ compatible with libicu of XeTeX
    if test -s /usr/include/layout/GlyphPositioningTables.h -a \
	-s /usr/include/layout/Features.h -a \
	-s /usr/include/common/cmemory.h \
	&& false
    then
	icu[0]='--with-system-icu'
	icu[1]='--with-icu-include=/usr/include/unicode -I/usr/include/layout -I/usr/include/common'
    else
	icu[0]=""
    fi
    # Wrong version string
    sed -ri '/m4_define.*tex_live_version/{s@[0-9]+/dev@%{texlive_version}@}' version.ac
    for rp in $(find -name configure) ; do
	sed -ri '/(Web2C|STRING|VERSION)/{s@[0-9]+/dev@%{texlive_version}@}' $rp
    done

    # Avoid -rpath as libtool is not configurable at this point
    for rp in $(find -name libtool.m4 -or -name configure) ; do
	sed -ri 's/(-rpath)/\1-link/g' $rp
    done
    LD_LIBRARY_PATH=${prefix}/lib:${world}/texk/kpathsea/.libs:${world}/texk/ptexenc/.libs
    export LD_LIBRARY_PATH

    # We have an other autoconf/automake version
    ./reautoconf libs/icu/dummy

    if [[ $VENDOR =~ opensuse ]] ; then
	banner='for opensuse.org'
    else
	banner='for SUSE Linux'
    fi
    #
    # Avoid win32 Makefile
    #
    find -name configure | xargs sed -ri '/(CONFIG_FILES|ac_config_files)=/ { s@[[:blank:]]+(otps/|)win32/Makefile@@p; }'

    # Run configure now ... no reautoconf here as TeX Live uses modified m4 macros
    # longinteger and off_t declarations are still inconsistent, do not enable
    # largefile unless you are testing.
    # Default to building ICU without thread support, since xetex does not need it.
    cache=$PWD/config.cache
    mkdir -p ${world}
    pushd ${world}/
	STRIP=/bin/true				\
	STRIPPROG=/bin/true			\
	../configure				\
	    --host=${HOST}			\
	    --build=${BUILD}			\
	    --disable-native-texlive-build	\
	    --disable-cxx-runtime-hack		\
	    --cache-file=$cache			\
	    --disable-multiplatform		\
	    --prefix=$prefix			\
	    --datadir=$prefix			\
	    --datarootdir=$prefix		\
	    --exec-prefix=$prefix		\
	    --bindir=$prefix/bin		\
	    --libdir=$prefix/lib		\
	    --infodir=$prefix/share/info	\
	    --mandir=$prefix/share/man		\
	    --sysconfdir=$prefix/etc		\
	    --localstatedir=$prefix/var/lib	\
	    --sharedstatedir=$prefix/var/lib	\
	    --includedir=$prefix/include	\
	    --x-libraries=%{_x11lib}		\
	    --x-includes=%{_x11inc}		\
	    --disable-cxx-runtime-hack		\
	    --disable-texinfo			\
	    --disable-texi2html			\
	    --disable-dialog			\
	    --disable-t1utils			\
	    --disable-dvi2tty			\
	    --disable-xindy			\
	    --disable-xindy-docs		\
	    --disable-xindy-rules		\
	    --disable-xz			\
	    --disable-largefile			\
	    --disable-threads			\
	    --%{!?with_psutils:disable}%{?with_psutils:enable}-psutils \
	    --%{!?with_lcdf_typetools:disable}%{?with_lcdf_typetools:enable}-lcdf-typetools \
	    --enable-freetype			\
	    --enable-musixflx			\
	    --enable-lacheck			\
	    --enable-detex			\
	    --enable-seetexk			\
	    --enable-tex4htk			\
	    --enable-shared			\
%if %{with LuaJIT}
	    --enable-luajittex			\
%else
	    --disable-luajittex			\
%endif
	    --with-gnu-ld			\
	    --with-gnu-libc			\
	    --with-system-xz			\
	    --with-system-dialog		\
	    --with-system-t1utils		\
	    --with-system-ncurses		\
	    --with-system-zlib			\
	    --with-system-expat			\
	    --with-system-unzip			\
%if %{with poppler}
	    --with-system-poppler		\
%endif
	    --with-system-xpdf			\
	    --with-system-libpng		\
	    --with-system-pnglib		\
	    --with-system-gd			\
	    --with-system-freetype		\
	    --with-system-zziplib		\
	    --with-system-libgs			\
	    --with-freetype-includes=/usr/include/freetype \
	    --with-system-freetype2		\
	    --with-freetype2-includes=/usr/include/freetype2 \
	    --with-system-cairo			\
	    --with-system-includes=/usr/include/cairo \
	    --with-system-mpfr			\
	    --with-system-harfbuzz		\
	    --with-system-icu			\
	    --with-system-graphite2		\
	    --with-system-potrace		\
	    --with-system-libpaper		\
	    --with-banner-add="/TeX Live $banner" \
	    ${icu[0]:+"${icu[@]}"}		\
	    --enable-epsfwin			\
	    --enable-mftalkwin			\
	    --enable-regiswin			\
	    --enable-tektronixwin		\
	    --enable-unitermwin			\
	    --with-ps=gs			\
	    --with-x				\
	    --with-mf-x-toolkit			\
	    --with-xdvi-x-toolkit=xaw3d		\
	    --with-editor='vi +%%d %%s'

	PATH=$prefix/bin:$PATH			\
	TEXMFLOCAL=%{_texmfmaindir}		\
	TEXMFCNF=$texmfcnf			\
	make %{?_smp_mflags} world STRIP=/bin/true STRIPPROG=/bin/true
    popd

    pushd utils/asymptote
	autoreconf
	(cat>libOSMesa.so)<<-'EOF'
		/* GNU ld script */
		INPUT(%{_libdir}/libOSMesa.so AS_NEEDED(-lglapi))
	EOF
	PATH=$prefix/bin:$PATH			\
	TEXMFLOCAL=%{_texmfmaindir}		\
	TEXMFCNF=$texmfcnf			\
	STRIP=/bin/true				\
	STRIPPROG=/bin/true			\
	LDFLAGS="$LDFLAGS -L$PWD"		\
	./configure				\
	    --host=${HOST}			\
	    --build=${BUILD}			\
	    --prefix=%{_prefix}			\
	    --bindir=%{_bindir}			\
	    --libdir=%{_libdir}			\
	    --datadir=%{_texmfmaindir}		\
	    --disable-texlive-build		\
	    --enable-offscreen			\
	    --enable-readline			\
	    --enable-gsl			\
	    --enable-fftw			\
	    --enable-gc=system			\
	    --enable-gl
	make asy
	mkdir -p ${prefix}/bin
	mkdir -p ${prefix}/texmf/asymptote/GUI
	install -m 0755 asy		${prefix}/bin/
	install -m 0755 GUI/xasy.py	${prefix}/texmf/asymptote/GUI
	ln -sf ../texmf/asymptote/GUI/xasy.py ${prefix}/bin/xasy
    popd

    # compile public
    mkdir -p ${prefix}/lib/mktex
    $CC ${RPM_OPT_FLAGS} -DTEXGRP='"%{texgrp}"' -DMKTEX='"%{_libexecdir}/mktex"' -fPIE -pie -o ${prefix}/lib/mktex/public %{S:50}

    # install our own scripts
    mkdir -p ${prefix}/bin
    install -m 0755 texk/seetexk/a4toa5 ${prefix}/bin/
    install -m 0755 texk/seetexk/mydvichk ${prefix}/bin/
    install -m 0755 texk/seetexk/odd2even ${prefix}/bin/

%if %{with LuaJIT}
    echo "Luaji is supported on this platform"
%else
    for broken in luajittex texluajit texluajitc
    do
	test ! -x ${prefix}/bin/$broken || continue
	(cat>${prefix}/bin/$broken)<<-'EOF'
	#!/bin/sh
	echo "${0}: is not supported on $(uname -m)" 1>&2
	exit 1
	EOF
	chmod 0755 ${prefix}/bin/$broken
	unset broken
    done
%endif

    # install perl modules
%if 0%{texlive_version} >= 2013
    mkdir -p ${prefix}/share/tlpkg/TeXLive
    install -m 0644 texk/tests/TeXLive/TLConfig.pm ${prefix}/share/tlpkg/TeXLive/
    install -m 0644 texk/tests/TeXLive/TLUtils.pm  ${prefix}/share/tlpkg/TeXLive/
%else
    mkdir -p ${prefix}/lib/tlpkg/TeXLive
    install -m 0644 texk/tests/TeXLive/TLConfig.pm ${prefix}/lib/tlpkg/TeXLive/
    install -m 0644 texk/tests/TeXLive/TLUtils.pm  ${prefix}/lib/tlpkg/TeXLive/
%endif

%if %{with buildbiber}
    # dump a biber executable
    pushd ../biblatex-biber-*
	find -name '*.ca' | xargs -r rm -vf

	LANG=en_US.UTF-8 %{__perl} ./Build.PL installdirs=vendor optimize="$RPM_OPT_FLAGS"
	LANG=en_US.UTF-8 ./Build build flags=%{?_smp_mflags}

	# There is no network here
	rm t/remote-files.t

	LANG=en_US.UTF-8 \
	BIBER_DEV_TESTS=1 \
	./Build test

%if 0%{suse_version} <= 1230
	pushd blib

	(cat > biber.files)<<-'EOF'
	../data/biber-tool.conf;lib/Biber/biber-tool.conf
	../data/schemata/config.rnc;lib/Biber/config.rnc
	../data/schemata/config.rng;lib/Biber/config.rng
	../data/schemata/bcf.rnc;lib/Biber/bcf.rnc
	../data/schemata/bcf.rng;lib/Biber/bcf.rng
	../data/schemata/biblatexml.rnc;lib/Biber/biblatexml.rnc
	../data/schemata/biblatexml.rng;lib/Biber/biblatexml.rng
	../lib/Biber/LaTeX/recode_data.xml;lib/Biber/LaTeX/recode_data.xml
	../data/bcf.xsl;lib/Biber/bcf.xsl
	../data/latinkeys.txt;lib/Unicode/Collate/latinkeys.txt
	%{perl_privlib}/Unicode/Collate/Locale;lib/Unicode/Collate/Locale
	%{perl_privlib}/Unicode/Collate/CJK;lib/Unicode/Collate/CJK
	%{perl_privlib}/Unicode/Collate/allkeys.txt;lib/Unicode/Collate/allkeys.txt
	%{perl_privlib}/Unicode/Collate/keys.txt;lib/Unicode/Collate/keys.txt
	%{perl_privlib}/PerlIO;lib/PerlIO
	%{perl_archlib}/auto/PerlIO;lib/auto/PerlIO
	%{perl_vendorlib}/Business/ISBN/RangeMessage.xml;lib/Business/ISBN/RangeMessage.xml
	EOF
	LD_LIBRARY_PATH=/%{_lib}:%{_libdir}		\
	PAR_VERBATIM=1					\
	pp -I lib --dependent				\
	    --compress=7				\
	    --module=deprecate				\
	    --module=Biber::Input::file::bibtex		\
	    --module=Biber::Input::file::biblatexml	\
	    --module=Biber::Input::file::ris		\
	    --module=Biber::Input::file::zoterordfxml	\
	    --module=Biber::Input::file::endnotexml	\
	    --module=Biber::Output::bibtex		\
	    --module=Biber::Output::biblatexml		\
	    --module=Pod::Simple::TranscodeSmart	\
	    --module=Pod::Simple::TranscodeDumb		\
	    --module=Encode::Byte			\
	    --module=Encode::CN				\
	    --module=Encode::CJKConstants		\
	    --module=Encode::EBCDIC			\
	    --module=Encode::Encoder			\
	    --module=Encode::GSM0338			\
	    --module=Encode::Guess			\
	    --module=Encode::JP				\
	    --module=Encode::KR				\
	    --module=Encode::MIME::Header		\
	    --module=Encode::Symbol			\
	    --module=Encode::TW				\
	    --module=Encode::Unicode			\
	    --module=Encode::Unicode::UTF7		\
	    --module=Encode::EUCJPASCII			\
	    --module=Encode::JIS2K			\
	    --module=Encode::HanExtra			\
	    --module=File::Find::Rule			\
	    --module=IO::Socket::SSL			\
	    --link=libbtparse.so			\
	    --link=libxml2.so				\
	    --link=libz.so				\
	    --link=libxslt.so				\
	    --link=libexslt.so				\
	    --link=libcrypto.so				\
	    --link=libssl.so				\
	    --addlist=biber.files			\
	    --cachedeps=scancache			\
	    --output=${prefix}/bin/biber		\
	    script/biber
	    install -m 0644 bindoc/biber.1 ${prefix}/share/man/man1/
	popd
%endif
    popd
%endif

%install

    # Read the options file
    . %{options}

    mkdir -p %{buildroot}%{_bindir}
    mkdir -p %{buildroot}%{_libdir}/pkgconfig
    mkdir -p %{buildroot}%{_includedir}
    mkdir -p %{buildroot}%{_infodir}
    mkdir -p %{buildroot}%{_libexecdir}/mktex
    mkdir -p %{buildroot}%{_libexecdir}/tlpkg/TeXLive
    mkdir -p %{buildroot}%{_mandir}
    mkdir -p %{buildroot}%{_mandir}/man1
    mkdir -p %{buildroot}%{_mandir}/man5
    mkdir -p %{buildroot}%{_mandir}/man8
    mkdir -p %{buildroot}%{_texmfmaindir}
    mkdir -p %{buildroot}%{_texmfdistdir}
    mkdir -p %{buildroot}%{_texmfconfdir}/dvipdfm/config
    mkdir -p %{buildroot}%{_texmfconfdir}/dvipdfmx
    mkdir -p %{buildroot}%{_texmfconfdir}/dvips/config
    mkdir -p %{buildroot}%{_texmfconfdir}/scripts/urlbst
    mkdir -p %{buildroot}%{_texmfconfdir}/scripts/match_parens
    mkdir -p %{buildroot}%{_texmfconfdir}/scripts/mf2pt1
    mkdir -p %{buildroot}%{_texmfconfdir}/tex/amstex/base
    mkdir -p %{buildroot}%{_texmfconfdir}/tex/generic/config
    mkdir -p %{buildroot}%{_texmfconfdir}/tex/lambda/config
    mkdir -p %{buildroot}%{_texmfconfdir}/tex/mex/base
    mkdir -p %{buildroot}%{_texmfconfdir}/tex/plain/cyrplain
    mkdir -p %{buildroot}%{_texmfconfdir}/web2c
    mkdir -p %{buildroot}%{_texmfconfdir}/xdvi
    mkdir -p %{buildroot}%{_texmfvardir}
    mkdir -p %{buildroot}%{_texmfvardir}/dist
    mkdir -p %{buildroot}%{_texmfvardir}/fonts
    mkdir -p %{buildroot}%{_texmfvardir}/fonts/dvipdfm
    mkdir -p %{buildroot}%{_texmfvardir}/fonts/dvips
    mkdir -p %{buildroot}%{_texmfvardir}/fonts/pdftex
    mkdir -p %{buildroot}%{_texmfvardir}/main
    mkdir -p %{buildroot}%{_texmfvardir}/md5
    mkdir -p %{buildroot}%{_texmfvardir}/web2c
    mkdir -p %{buildroot}%{_texmfvardir}/web2c/aleph
    mkdir -p %{buildroot}%{_texmfvardir}/web2c/eptex
    mkdir -p %{buildroot}%{_texmfvardir}/web2c/luatex
    mkdir -p %{buildroot}%{_texmfvardir}/web2c/metafont
    mkdir -p %{buildroot}%{_texmfvardir}/web2c/pdftex
    mkdir -p %{buildroot}%{_texmfvardir}/web2c/ptex
    mkdir -p %{buildroot}%{_texmfvardir}/web2c/tex
    mkdir -p %{buildroot}%{_texmfvardir}/web2c/xetex
    mkdir -p %{buildroot}%{_texmfcache}
    mkdir -p %{buildroot}%{_fontcache}
    mkdir -p %{buildroot}%{_fontcache}/pk
    mkdir -p %{buildroot}%{_fontcache}/source
    mkdir -p %{buildroot}%{_fontcache}/tfm
    mkdir -p %{buildroot}%{_appdefdir}
    mkdir -p %{buildroot}/var/adm/update-scripts

    pushd ${prefix}/bin/
	tar -cpSf - . | tar -xvspSf - -C %{buildroot}%{_bindir}/
	rm -vf %{buildroot}%{_bindir}/tlmgr
	rm -vf %{buildroot}%{_bindir}/installfont-tl
    popd
    pushd ${prefix}/lib/
	tar -cpSf - *.so* | tar -xvspSf - -C %{buildroot}%{_libdir}/
	tar -cpSf - mktex | tar -xvspSf - -C %{buildroot}%{_libexecdir}/
    popd
%if 0%{texlive_version} < 2013
    pushd ${prefix}/lib/
	tar -cpSf - tlpkg | tar -xvspSf - -C %{buildroot}%{_libexecdir}/
    popd
%else
    pushd ${prefix}/share/
	tar -cpSf - tlpkg | tar -xvspSf - -C %{buildroot}%{_datadir}/
    popd
%endif
    pushd ${prefix}/include/
	tar -cpSf - . | tar -xvspSf - -C %{buildroot}%{_includedir}/
    popd
    pushd ${prefix}/share/man/
%if %{with buildbiber}
%if 0%{suse_version} <= 1230
	install -m 0644 man1/biber.1 %{buildroot}%{_mandir}/man1/
%endif
%endif
%if 0%{texlive_version} < 2013
	install -m 0644 man1/pmx2pdf.1 %{buildroot}%{_mandir}/man1/
	install -m 0644 man1/pmxab.1 %{buildroot}%{_mandir}/man1/
	install -m 0644 man1/prepmx.1 %{buildroot}%{_mandir}/man1/
	install -m 0644 man1/m-tx.1 %{buildroot}%{_mandir}/man1/
	install -m 0644 man1/scor2prt.1 %{buildroot}%{_mandir}/man1/
%endif
    popd
    #
    # Biber support
    #
%if %{with buildbiber}
%if 0%{suse_version} > 1230
    pushd ../biblatex-biber-*
	./Build install destdir=%{buildroot}
	chmod    0755 %{buildroot}%{_bindir}/biber
	rm -vf        %{buildroot}%{_mandir}/man1/biber.1*
	chmod    0644 %{buildroot}%{perl_vendorlib}/Biber.pm
	chmod -R u+rw %{buildroot}%{perl_vendorlib}/Biber
	chmod -R u+rw %{buildroot}%{perl_vendorlib}/Unicode/Collate/*
	rm -vrf %{buildroot}%{perl_vendorarch}/auto
	rm -vrf %{buildroot}%{_mandir}/man3
	%perl_process_packlist
	%perl_gen_filelist
	pushd blib
	    install -m 0644 bindoc/biber.1 %{buildroot}%{_mandir}/man1/
	popd
	sed -ri '\@/usr/(share|bin)/.*@d' texlive.files
    popd
    mv ../biblatex-biber-*/texlive.files perl-biber.files
%endif
%endif

    #
    # Those lines with exclamation mark have to done in the
    # specific spec files
    #
#!  pushd ${prefix}/share/info/
#!	tar -cpSf - *.info | tar -xvspSf - -C %{buildroot}%{_infodir}/
#!  popd
#!  pushd ${prefix}/share/man/
#!	tar -cpSf - . | tar -xvspSf - -C %{buildroot}%{_mandir}/
#!	rm -vf %{buildroot}%{_mandir}/man*/tlmgr*
#!	rm -vf %{buildroot}%{_mandir}/man*/installfont-tl*
#!  popd
    pushd ${prefix}/texmf/
	tar -cpSf - . | tar -xvspSf - -C %{buildroot}%{_texmfmaindir}/
	rm -vrf %{buildroot}%{_texmfmaindir}/texconfig/g
	rm -vrf %{buildroot}%{_texmfmaindir}/texconfig/v
	rm -vrf %{buildroot}%{_texmfmaindir}/texconfig/x
	rm -vrf %{buildroot}%{_texmfmaindir}/tlpkg/tlpobj
	rm -vf  %{buildroot}%{_texmfmaindir}/texconfig/generic
	rm -vf  %{buildroot}%{_texmfmaindir}/texconfig/README
#!	mv -vf  %{buildroot}%{_texmfmaindir}/dvipdfmx/dvipdfmx.cfg \
#!		%{buildroot}%{_texmfconfdir}/dvipdfmx/
#!	ln -sf		    %{_texmfconfdir}/dvipdfmx/dvipdfmx.cfg \
#!		%{buildroot}%{_texmfmaindir}/dvipdfmx/
	for cnf in %{buildroot}%{_texmfmaindir}/web2c/*.cnf ; do
	    test -e "$cnf" || break
	    mv -vf $cnf %{buildroot}%{_texmfconfdir}/web2c/
	    ln -sf %{_texmfconfdir}/web2c/${cnf##*/} $cnf
	done
#!	mv -vf  %{buildroot}%{_texmfmaindir}/xdvi/xdvi.cfg \
#!		%{buildroot}%{_texmfconfdir}/xdvi/
#!	ln -sf		    %{_texmfconfdir}/xdvi/xdvi.cfg \
#!		%{buildroot}%{_texmfmaindir}/xdvi/
#!	mv -vf  %{buildroot}%{_texmfmaindir}/xdvi/XDvi \
#!		%{buildroot}%{_texmfconfdir}/xdvi/
#!	ln -sf		    %{_texmfconfdir}/xdvi/XDvi \
#!		%{buildroot}%{_appdefdir}/
    popd
    pushd ${prefix}/texmf-dist/
	tar -cpSf - . | tar -xvspSf - -C %{buildroot}%{_texmfdistdir}/
	rm -vrf %{buildroot}%{_texmfdistdir}/texconfig/g
	rm -vrf %{buildroot}%{_texmfdistdir}/texconfig/v
	rm -vrf %{buildroot}%{_texmfdistdir}/texconfig/x
	rm -vrf %{buildroot}%{_texmfdistdir}/tlpkg/tlpobj
	rm -vf  %{buildroot}%{_texmfdistdir}/texconfig/generic
	rm -vf  %{buildroot}%{_texmfdistdir}/texconfig/README
	for cnf in %{buildroot}%{_texmfdistdir}/web2c/*.cnf ; do
	    test -e "$cnf" || break
	    mv -vf $cnf %{buildroot}%{_texmfconfdir}/web2c/
	    ln -sf %{_texmfconfdir}/web2c/${cnf##*/} $cnf
	done
    popd
    pushd %{buildroot}%{_bindir}/
	# ppower4 (currently) not part of TEX Live
	rm -f pdfthumb
	rm -f ppower4
	# repair/relocate the script links
	find -type l -printf '%f\a%l\n' | \
	    while IFS=$'\a' read dst src; do
		case "$src" in
%if 0%{texlive_version} >= 2013
		*/texmf/*)	ln -sf ../share/texmf/${src#../texmf/}	    $dst ;;
%else
		*/texmf/*)	ln -sf ../lib/texmf/${src#../texmf/}	    $dst ;;
%endif
		*/texmf-dist/*)	ln -sf ../share/texmf/${src#../texmf-dist/} $dst ;;
		esac
	    done
	# set xasy script link
%if 0%{texlive_version} >= 2013
	ln -sf ../share/texmf/asymptote/GUI/xasy.py xasy
%else
	ln -sf ../lib/texmf/asymptote/GUI/xasy.py xasy
%endif
	# some scripts not included in main source tar ball
	test -e match_parens || ln -sf ../share/texmf/scripts/match_parens/match_parens match_parens
	test -e mf2pt1       || ln -sf ../share/texmf/scripts/mf2pt1/mf2pt1.pl mf2pt1
	test -e urlbst       || ln -sf ../share/texmf/scripts/urlbst/urlbst urlbst
	# set some may missed symbolic links
	test -e mfplain  || ln -vsf mpost    mfplain
	test -e texlua   || ln -vsf luatex   texlua
	test -e texluac  || ln -vsf luatex   texluac
	test -e texhash  || ln -vsf mktexlsr texhash
	test -e rpdfcrop || ln -vsf pdfcrop  rpdfcrop
	# stolen from texlink script, also added musixtex case
	sed -r '\@^[[:blank:]]*(#|$)@d;s@\*@@' < $prefix/texmf-dist/web2c/fmtutil.cnf | \
	awk '{print $1, $2 }' | while read fmt engine ; do
	    test -f "$engine" || continue
	    case "$fmt" in
	    mf) test "$engine" = mf-nowin -a -f mfw && engine=mfw
	    esac
	    case "$fmt" in
	    cont-??|mptopdf|*musixtex) continue ;;
	    *)  test "$fmt" = "$(ls -ld "$fmt" 2> /dev/null | awk '{print $NF}')" || rm -rf "$fmt"
		test ! -f "$fmt" || continue
		ln -vsf "$engine" "$fmt"
	    esac
	done
	# our pdfmusixtex extension of the musixtex lua script
	test -e pdfmusixtex  || ln -sf musixtex pdfmusixtex
	if test ! -e rlxtools ; then
	    printf '#!/bin/sh\nmtxrun --script rlxtools "$@"\n' > rlxtools
	    chmod 755 rlxtools
	fi
    popd

    # clear out all file below texmf tree as this will delivered by texlive tar balls
    find %{buildroot}%{_texmfdirs} -type f | xargs -r rm -vf

    # but work around missing MusixTeX files ...
%if 0%{texlive_version} < 2013
    pushd ${prefix}/texmf-dist/
	install -m 0755 scripts/m-tx/m-tx.lua %{buildroot}%{_texmfdistdir}/scripts/m-tx/
	install -m 0755 scripts/pmx/pmx2pdf.lua %{buildroot}%{_texmfdistdir}/scripts/pmx/
    popd
%endif
    # ... and add rungs texlua script as dvipdfmx/dvipdfm require this
    pushd ${prefix}/texmf-dist/
	install -m 0755 scripts/texlive/rungs.tlu %{buildroot}%{_texmfdistdir}/scripts/texlive/
    popd

    # install manual page of public
    install -m 0644 %{S:51} %{buildroot}%{_mandir}/man8/public.8

    # is part of texlive-kpathsea
    rm -vf %{buildroot}%{_texmfconfdir}/web2c/fmtutil.cnf
    rm -vf %{buildroot}%{_texmfconfdir}/web2c/texmf.cnf
    rm -vf %{buildroot}%{_texmfmaindir}/web2c/fmtutil.cnf
    rm -vf %{buildroot}%{_texmfmaindir}/web2c/texmf.cnf
    rm -vf %{buildroot}%{_texmfdistdir}/web2c/fmtutil.cnf
    rm -vf %{buildroot}%{_texmfdistdir}/web2c/texmf.cnf

    # relink texlive helpers to public binary
    for mktex in texhash mktexlsr mktexmf mktexpk mktextfm
    do
	mv -f %{buildroot}%{_bindir}/$mktex %{buildroot}%{_libexecdir}/mktex/
	ln -sf %{_libexecdir}/mktex/public %{buildroot}%{_bindir}/$mktex
    done

    ln -sf %{_texmfdistdir}/texconfig/zypper.py \
	%{buildroot}/var/adm/update-scripts/%{name}-%{version}-%{release}-zypper

    pushd ${prefix}/lib/pkgconfig/
    for pc in kpathsea ptexenc texlua52 texluajit synctex
    do
	test -e "$pc.pc" || continue
	sed -ri "s@([^=]+=)${prefix}@\1/usr@" $pc.pc
	install -m 0644 $pc.pc %{buildroot}%{_libdir}/pkgconfig/
    done
    popd

    pushd ${world}/texk/kpathsea/
	install -m 0644 c-auto.h %{buildroot}%{_includedir}/kpathsea/
    popd

%if %{defined verify_permissions}
%verifyscript kpathsea-bin
%verify_permissions -e %{_libexecdir}/mktex/public
%endif

%pre kpathsea-bin
if test "$1" = 1 -a -z "$(%{_bindir}/getent group %{texgrp} 2>/dev/null)"; then
    %{_sbindir}/groupadd -r %{?texgid:-g %texgid} %{texgrp}
fi

%post kpathsea-bin
%if %{defined set_permissions}
%set_permissions %{_libexecdir}/mktex/public
%endif

%post
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun
if test $1 = 1; then
    mkdir -p /var/run/texlive
    > /var/run/texlive/run-mktexlsr
    > /var/run/texlive/run-update
fi

%posttrans
test -f /var/run/texlive/run-update || exit 0
test -z "$ZYPP_IS_RUNNING" || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :
rm -f /var/run/texlive/run-update

%post   -n libkpathsea6 -p /sbin/ldconfig
%postun -n libkpathsea6 -p /sbin/ldconfig

%post   -n libptexenc1 -p /sbin/ldconfig
%postun -n libptexenc1 -p /sbin/ldconfig

%post   -n libsynctex1 -p /sbin/ldconfig
%postun -n libsynctex1 -p /sbin/ldconfig

%post   -n libtexlua52-5 -p /sbin/ldconfig
%postun -n libtexlua52-5 -p /sbin/ldconfig

%if %{with LuaJIT}
%post   -n libtexluajit2 -p /sbin/ldconfig
%postun -n libtexluajit2 -p /sbin/ldconfig
%endif

%files
%defattr(-,root,root,755)
%if 0%{texlive_version} >= 2013
%{_datadir}/tlpkg/TeXLive/TLConfig.pm
%{_datadir}/tlpkg/TeXLive/TLUtils.pm
%else
%{_libexecdir}/tlpkg/TeXLive/TLConfig.pm
%{_libexecdir}/tlpkg/TeXLive/TLUtils.pm
%endif
# is part of texlive-kpathsea
#%config(noreplace) %verify(not md5 size mtime) %{_texmfconfdir}/web2c/fmtutil.cnf
#%config(noreplace) %verify(not md5 size mtime) %{_texmfconfdir}/web2c/texmf.cnf
#%verify(link) %{_texmfmaindir}/web2c/fmtutil.cnf
#%verify(link) %{_texmfmaindir}/web2c/texmf.cnf
%{_mandir}/man8/public.*
%verify(link) /var/adm/update-scripts/%{name}-%{version}-%{release}-zypper

%files a2ping-bin
%defattr(-,root,root,755)
%{_bindir}/a2ping

%files accfonts-bin
%defattr(-,root,root,755)
%{_bindir}/mkt1font
%{_bindir}/vpl2ovp
%{_bindir}/vpl2vpl

%files adhocfilelist-bin
%defattr(-,root,root,755)
%{_bindir}/adhocfilelist

%files afm2pl-bin
%defattr(-,root,root,755)
%{_bindir}/afm2pl

%files aleph-bin
%defattr(-,root,root,755)
%{_bindir}/aleph
%{_bindir}/lamed

%files amstex-bin
%defattr(-,root,root,755)
%{_bindir}/amstex

%files arara-bin
%defattr(-,root,root,755)
%{_bindir}/arara

%files asymptote-bin
%defattr(-,root,root,755)
%{_bindir}/asy
%{_bindir}/xasy

%files authorindex-bin
%defattr(-,root,root,755)
%{_bindir}/authorindex

%files biber-bin
%defattr(-,root,root,755)
%{_bindir}/biber
%if %{with buildbiber}
%{_mandir}/man1/biber.1*
%endif

%files bibexport-bin
%defattr(-,root,root,755)
%{_bindir}/bibexport

%files bibtex-bin
%defattr(-,root,root,755)
%{_bindir}/bibtex

%files bibtex8-bin
%defattr(-,root,root,755)
%{_bindir}/bibtex8

%files bibtexu-bin
%defattr(-,root,root,755)
%{_bindir}/bibtexu

%files bundledoc-bin
%defattr(-,root,root,755)
%{_bindir}/arlatex
%{_bindir}/bundledoc

%files cachepic-bin
%defattr(-,root,root,755)
%{_bindir}/cachepic

%files checkcites-bin
%defattr(-,root,root,755)
%{_bindir}/checkcites

%files chktex-bin
%defattr(-,root,root,755)
%{_bindir}/chktex
%{_bindir}/chkweb
%{_bindir}/deweb

%files cjk-gs-integrate-bin
%defattr(-,root,root,755)
%{_bindir}/cjk-gs-integrate

%files cjkutils-bin
%defattr(-,root,root,755)
%{_bindir}/bg5+latex
%{_bindir}/bg5+pdflatex
%{_bindir}/bg5conv
%{_bindir}/bg5latex
%{_bindir}/bg5pdflatex
%{_bindir}/cef5conv
%{_bindir}/cef5latex
%{_bindir}/cef5pdflatex
%{_bindir}/cefconv
%{_bindir}/ceflatex
%{_bindir}/cefpdflatex
%{_bindir}/cefsconv
%{_bindir}/cefslatex
%{_bindir}/cefspdflatex
%{_bindir}/extconv
%{_bindir}/gbklatex
%{_bindir}/gbkpdflatex
%{_bindir}/hbf2gf
%{_bindir}/sjisconv
%{_bindir}/sjislatex
%{_bindir}/sjispdflatex

%files context-bin
%defattr(-,root,root,755)
%{_bindir}/context
%{_bindir}/contextjit
%{_bindir}/luatools
%{_bindir}/mtxrun
%{_bindir}/rlxtools
%{_bindir}/mtxrunjit
%{_bindir}/texexec
%{_bindir}/texmfstart

%files convbkmk-bin
%defattr(-,root,root,755)
%{_bindir}/convbkmk

%files crossrefware-bin
%defattr(-,root,root,755)
%{_bindir}/bibdoiadd
%{_bindir}/bibzbladd
%{_bindir}/ltx2crossrefxml

%files cslatex-bin
%defattr(-,root,root,755)
%{_bindir}/cslatex
%{_bindir}/pdfcslatex

%files csplain-bin
%defattr(-,root,root,755)
%{_bindir}/csplain
%{_bindir}/pdfcsplain

%files ctanify-bin
%defattr(-,root,root,755)
%{_bindir}/ctanify

%files ctanupload-bin
%defattr(-,root,root,755)
%{_bindir}/ctanupload

%files ctie-bin
%defattr(-,root,root,755)
%{_bindir}/ctie

%files cweb-bin
%defattr(-,root,root,755)
%{_bindir}/ctangle
%{_bindir}/cweave

%files cyrillic-bin-bin
%defattr(-,root,root,755)
%{_bindir}/rubibtex
%{_bindir}/rumakeindex

%files de-macro-bin
%defattr(-,root,root,755)
%{_bindir}/de-macro

%files detex-bin
%defattr(-,root,root,755)
%{_bindir}/detex

%files devnag-bin
%defattr(-,root,root,755)
%{_bindir}/devnag

%files diadia-bin
%defattr(-,root,root,755)
%{_bindir}/diadia

%files dosepsbin-bin
%defattr(-,root,root,755)
%{_bindir}/dosepsbin

%files dtl-bin
%defattr(-,root,root,755)
%{_bindir}/dt2dv
%{_bindir}/dv2dt

%files dtxgen-bin
%defattr(-,root,root,755)
%{_bindir}/dtxgen

%files dviasm-bin
%defattr(-,root,root,755)
%{_bindir}/dviasm

%files dvicopy-bin
%defattr(-,root,root,755)
%{_bindir}/dvicopy

%files dvidvi-bin
%defattr(-,root,root,755)
%{_bindir}/dvidvi

%files dviljk-bin
%defattr(-,root,root,755)
%{_bindir}/dvihp
%{_bindir}/dvilj
%{_bindir}/dvilj2p
%{_bindir}/dvilj4
%{_bindir}/dvilj4l
%{_bindir}/dvilj6

%files dvipdfmx-bin
%defattr(-,root,root,755)
%{_bindir}/dvipdfm
%{_bindir}/dvipdfmx
%{_bindir}/rungs
%{_texmfdistdir}/scripts/texlive/rungs.tlu
%{_bindir}/dvipdft
%{_bindir}/ebb
%{_bindir}/extractbb

%files dvipng-bin
%defattr(-,root,root,755)
%{_bindir}/dvigif
%{_bindir}/dvipng

%files dvipos-bin
%defattr(-,root,root,755)
%{_bindir}/dvipos

%files dvips-bin
%defattr(-,root,root,755)
%{_bindir}/afm2tfm
%{_bindir}/dvips

%files dvisvgm-bin
%defattr(-,root,root,755)
%{_bindir}/dvisvgm

%files ebong-bin
%defattr(-,root,root,755)
%{_bindir}/ebong

%files eplain-bin
%defattr(-,root,root,755)
%{_bindir}/eplain

%files epspdf-bin
%defattr(-,root,root,755)
%{_bindir}/epspdf
%{_bindir}/epspdftk

%files epstopdf-bin
%defattr(-,root,root,755)
%{_bindir}/epstopdf
%{_bindir}/repstopdf

%files exceltex-bin
%defattr(-,root,root,755)
%{_bindir}/exceltex

%files fig4latex-bin
%defattr(-,root,root,755)
%{_bindir}/fig4latex

%files findhyph-bin
%defattr(-,root,root,755)
%{_bindir}/findhyph

%files fontinst-bin
%defattr(-,root,root,755)
%{_bindir}/fontinst

%files fontools-bin
%defattr(-,root,root,755)
%{_bindir}/afm2afm
%{_bindir}/autoinst
%{_bindir}/ot2kpx

%files fontware-bin
%defattr(-,root,root,755)
%{_bindir}/pltotf
%{_bindir}/tftopl
%{_bindir}/vftovp
%{_bindir}/vptovf

%files fragmaster-bin
%defattr(-,root,root,755)
%{_bindir}/fragmaster

%files getmap-bin
%defattr(-,root,root,755)
%{_bindir}/getmapdl

%files glossaries-bin
%defattr(-,root,root,755)
%{_bindir}/makeglossaries
%{_bindir}/makeglossaries-lite

%files gsftopk-bin
%defattr(-,root,root,755)
%{_bindir}/gsftopk

%files jadetex-bin
%defattr(-,root,root,755)
%{_bindir}/jadetex
%{_bindir}/pdfjadetex

%files jfontmaps-bin
%defattr(-,root,root,755)
%{_bindir}/kanji-config-updmap
%{_bindir}/kanji-config-updmap-sys
%{_bindir}/kanji-fontmap-creator

%files kotex-utils-bin
%defattr(-,root,root,755)
%{_bindir}/jamo-normalize
%{_bindir}/komkindex
%{_bindir}/ttf2kotexfont

%files kpathsea-bin
%defattr(-,root,root,755)
%{_bindir}/kpseaccess
%{_bindir}/kpsereadlink
%{_bindir}/kpsestat
%{_bindir}/kpsewhich
%{_bindir}/mkocp
%{_bindir}/mkofm
%{_bindir}/mktexfmt
%{_bindir}/mktexlsr
%{_bindir}/mktexmf
%{_bindir}/mktexpk
%{_bindir}/mktextfm
%{_bindir}/texhash
%attr(0755,root,%{texgrp}) %{_libexecdir}/mktex/public
%{_libexecdir}/mktex/*tex*

%files lacheck-bin
%defattr(-,root,root,755)
%{_bindir}/lacheck

%files latex-bin-bin
%defattr(-,root,root,755)
%{_bindir}/dvilualatex
%{_bindir}/latex
%{_bindir}/lualatex
%{_bindir}/pdflatex

%files latex-git-log-bin
%defattr(-,root,root,755)
%{_bindir}/latex-git-log

%files latex2man-bin
%defattr(-,root,root,755)
%{_bindir}/latex2man

%files latexdiff-bin
%defattr(-,root,root,755)
%{_bindir}/latexdiff
%{_bindir}/latexdiff-vc
%{_bindir}/latexrevise

%files latexfileversion-bin
%defattr(-,root,root,755)
%{_bindir}/latexfileversion

%files latexindent-bin
%defattr(-,root,root,755)
%{_bindir}/latexindent

%files latexmk-bin
%defattr(-,root,root,755)
%{_bindir}/latexmk

%files latexpand-bin
%defattr(-,root,root,755)
%{_bindir}/latexpand

%files lcdftypetools-bin
%defattr(-,root,root,755)
%if %{with lcdf_typetools}
%{_bindir}/cfftot1
%{_bindir}/mmafm
%{_bindir}/mmpfb
%{_bindir}/otfinfo
%{_bindir}/otftotfm
%{_bindir}/t1dotlessj
%{_bindir}/t1lint
%{_bindir}/t1rawafm
%{_bindir}/t1reencode
%{_bindir}/t1testpage
%{_bindir}/ttftotype42
%endif

%files lilyglyphs-bin
%defattr(-,root,root,755)
%{_bindir}/lily-glyph-commands
%{_bindir}/lily-image-commands
%{_bindir}/lily-rebuild-pdfs

%files listbib-bin
%defattr(-,root,root,755)
%{_bindir}/listbib

%files listings-ext-bin
%defattr(-,root,root,755)
%{_bindir}/listings-ext.sh

%files lollipop-bin
%defattr(-,root,root,755)
%{_bindir}/lollipop
%{_bindir}/lualollipop
%{_bindir}/xelollipop

%files ltxfileinfo-bin
%defattr(-,root,root,755)
%{_bindir}/ltxfileinfo

%files ltximg-bin
%defattr(-,root,root,755)
%{_bindir}/ltximg

%files lua2dox-bin
%defattr(-,root,root,755)
%{_bindir}/lua2dox_filter

%files luaotfload-bin
%defattr(-,root,root,755)
%{_bindir}/luaotfload-tool

%files luatex-bin
%defattr(-,root,root,755)
%{_bindir}/dviluatex
%{_bindir}/luajittex
%{_bindir}/luatex
%{_bindir}/texlua
%{_bindir}/texluac
%{_bindir}/texluajit
%{_bindir}/texluajitc

%files m-tx-bin
%defattr(-,root,root,755)
%{_bindir}/m-tx
%{_bindir}/prepmx

%files make4ht-bin
%defattr(-,root,root,755)
%{_bindir}/make4ht

%files makeindex-bin
%defattr(-,root,root,755)
%{_bindir}/makeindex
%{_bindir}/mkindex

%files match_parens-bin
%defattr(-,root,root,755)
%{_bindir}/match_parens

%files mathspic-bin
%defattr(-,root,root,755)
%{_bindir}/mathspic

%files metafont-bin
%defattr(-,root,root,755)
%{_bindir}/inimf
%{_bindir}/mf
%{_bindir}/mf-nowin

%files metapost-bin
%defattr(-,root,root,755)
%{_bindir}/dvitomp
%{_bindir}/mfplain
%{_bindir}/mpost

%files mex-bin
%defattr(-,root,root,755)
%{_bindir}/mex
%{_bindir}/pdfmex
%{_bindir}/utf8mex

%files mf2pt1-bin
%defattr(-,root,root,755)
%{_bindir}/mf2pt1

%files mfware-bin
%defattr(-,root,root,755)
%{_bindir}/gftodvi
%{_bindir}/gftopk
%{_bindir}/gftype
%{_bindir}/mft
%{_bindir}/pktogf
%{_bindir}/pktype

%files mkgrkindex-bin
%defattr(-,root,root,755)
%{_bindir}/mkgrkindex

%files mkjobtexmf-bin
%defattr(-,root,root,755)
%{_bindir}/mkjobtexmf

%files mkpic-bin
%defattr(-,root,root,755)
%{_bindir}/mkpic

%files mltex-bin
%defattr(-,root,root,755)
%{_bindir}/mllatex
%{_bindir}/mltex

%files mptopdf-bin
%defattr(-,root,root,755)
%{_bindir}/mptopdf

%files multibibliography-bin
%defattr(-,root,root,755)
%{_bindir}/multibibliography

%files musixtex-bin
%defattr(-,root,root,755)
%{_bindir}/musixflx
%{_bindir}/musixtex
%{_bindir}/pdfmusixtex

%files musixtnt-bin
%defattr(-,root,root,755)
%{_bindir}/fixmsxpart
%{_bindir}/msxlint

%files omegaware-bin
%defattr(-,root,root,755)
%{_bindir}/odvicopy
%{_bindir}/odvitype
%{_bindir}/ofm2opl
%{_bindir}/omfonts
%{_bindir}/opl2ofm
%{_bindir}/otangle
%{_bindir}/otp2ocp
%{_bindir}/outocp
%{_bindir}/ovf2ovp
%{_bindir}/ovp2ovf
%{_bindir}/wofm2opl
%{_bindir}/wopl2ofm
%{_bindir}/wovf2ovp

%files patgen-bin
%defattr(-,root,root,755)
%{_bindir}/patgen

%files pax-bin
%defattr(-,root,root,755)
%{_bindir}/pdfannotextractor

%files pdfbook2-bin
%defattr(-,root,root,755)
%{_bindir}/pdfbook2

%files pdfcrop-bin
%defattr(-,root,root,755)
%{_bindir}/pdfcrop
%{_bindir}/rpdfcrop

%files pdfjam-bin
%defattr(-,root,root,755)
%{_bindir}/pdf180
%{_bindir}/pdf270
%{_bindir}/pdf90
%{_bindir}/pdfbook
%{_bindir}/pdfflip
%{_bindir}/pdfjam
%{_bindir}/pdfjam-pocketmod
%{_bindir}/pdfjam-slides3up
%{_bindir}/pdfjam-slides6up
%{_bindir}/pdfjoin
%{_bindir}/pdfnup
%{_bindir}/pdfpun

%files pdftex-bin
%defattr(-,root,root,755)
%{_bindir}/etex
%{_bindir}/pdfetex
%{_bindir}/pdftex
%{_bindir}/simpdftex

%files pdftools-bin
%defattr(-,root,root,755)
%{_bindir}/e2pall
%{_bindir}/pdfatfi
%{_bindir}/pdfclose
%{_bindir}/pdfopen
%{_bindir}/pdftosrc

%files pedigree-perl-bin
%defattr(-,root,root,755)
%{_bindir}/pedigree

%files perltex-bin
%defattr(-,root,root,755)
%{_bindir}/perltex

%files pfarrei-bin
%defattr(-,root,root,755)
%{_bindir}/a5toa4
%{_bindir}/pfarrei

%files pkfix-helper-bin
%defattr(-,root,root,755)
%{_bindir}/pkfix-helper

%files pkfix-bin
%defattr(-,root,root,755)
%{_bindir}/pkfix

%files pmx-bin
%defattr(-,root,root,755)
%{_bindir}/pmx2pdf
%{_bindir}/pmxab
%{_bindir}/scor2prt

%files pmxchords-bin
%defattr(-,root,root,755)
%{_bindir}/pmxchords

%files ps2pk-bin
%defattr(-,root,root,755)
%{_bindir}/mag
%{_bindir}/pfb2pfa
%{_bindir}/pk2bm
%{_bindir}/ps2pk

%files pst-pdf-bin
%defattr(-,root,root,755)
%{_bindir}/ps4pdf

%files pst2pdf-bin
%defattr(-,root,root,755)
%{_bindir}/pst2pdf

%files pstools-bin
%defattr(-,root,root,755)
%{_bindir}/bbox
%{_bindir}/ps2eps
%{_bindir}/ps2frag
%{_bindir}/pslatex

%files ptex-bin
%defattr(-,root,root,755)
%{_bindir}/eptex
%{_bindir}/makejvf
%{_bindir}/mendex
%{_bindir}/pbibtex
%{_bindir}/pdvitomp
%{_bindir}/pdvitype
%{_bindir}/platex
%{_bindir}/pmpost
%{_bindir}/ppltotf
%{_bindir}/ptex
%{_bindir}/ptftopl

%files ptex2pdf-bin
%defattr(-,root,root,755)
%{_bindir}/ptex2pdf

%files purifyeps-bin
%defattr(-,root,root,755)
%{_bindir}/purifyeps

%files pygmentex-bin
%defattr(-,root,root,755)
%{_bindir}/pygmentex

%files pythontex-bin
%defattr(-,root,root,755)
%{_bindir}/depythontex
%{_bindir}/pythontex

%files rubik-bin
%defattr(-,root,root,755)
%{_bindir}/rubikrotation

%files seetexk-bin
%defattr(-,root,root,755)
%{_bindir}/dvibook
%{_bindir}/dviconcat
%{_bindir}/dviselect
%{_bindir}/dvitodvi
%{_bindir}/a4toa5
%{_bindir}/mydvichk
%{_bindir}/odd2even

%files splitindex-bin
%defattr(-,root,root,755)
%{_bindir}/splitindex

%files sty2dtx-bin
%defattr(-,root,root,755)
%{_bindir}/sty2dtx

%files svn-multi-bin
%defattr(-,root,root,755)
%{_bindir}/svn-multi

%files synctex-bin
%defattr(-,root,root,755)
%{_bindir}/synctex

%files tetex-bin
%defattr(-,root,root,755)
%{_bindir}/allcm
%{_bindir}/allec
%{_bindir}/allneeded
%{_bindir}/dvi2fax
%{_bindir}/dvired
%{_bindir}/fmtutil
%{_bindir}/fmtutil-sys
%{_bindir}/kpsepath
%{_bindir}/kpsetool
%{_bindir}/kpsewhere
%{_bindir}/kpsexpand
%{_bindir}/texconfig-dialog
%{_bindir}/texconfig-sys
%{_bindir}/texlinks
%{_bindir}/updmap
%{_bindir}/updmap-sys

%files tex-bin
%defattr(-,root,root,755)
%{_bindir}/initex
%{_bindir}/tex

%files tex4ebook-bin
%defattr(-,root,root,755)
%{_bindir}/tex4ebook

%files tex4ht-bin
%defattr(-,root,root,755)
%{_bindir}/ht
%{_bindir}/htcontext
%{_bindir}/htlatex
%{_bindir}/htmex
%{_bindir}/httex
%{_bindir}/httexi
%{_bindir}/htxelatex
%{_bindir}/htxetex
%{_bindir}/mk4ht
%{_bindir}/t4ht
%{_bindir}/tex4ht

%files texconfig-bin
%defattr(-,root,root,755)
%{_bindir}/texconfig

%files texcount-bin
%defattr(-,root,root,755)
%{_bindir}/texcount

%files texdef-bin
%defattr(-,root,root,755)
%{_bindir}/texdef

%files texdiff-bin
%defattr(-,root,root,755)
%{_bindir}/texdiff

%files texdirflatten-bin
%defattr(-,root,root,755)
%{_bindir}/texdirflatten

%files texdoc-bin
%defattr(-,root,root,755)
%{_bindir}/texdoc
%{_bindir}/texdoctk

%files texfot-bin
%defattr(-,root,root,755)
%{_bindir}/texfot

%files texliveonfly-bin
%defattr(-,root,root,755)
%{_bindir}/texliveonfly

%files texloganalyser-bin
%defattr(-,root,root,755)
%{_bindir}/texloganalyser

%files texsis-bin
%defattr(-,root,root,755)
%{_bindir}/texsis

%files texware-bin
%defattr(-,root,root,755)
%{_bindir}/dvitype
%{_bindir}/pooltype

%files thumbpdf-bin
%defattr(-,root,root,755)
%{_bindir}/thumbpdf

%files tie-bin
%defattr(-,root,root,755)
%{_bindir}/tie

%files tpic2pdftex-bin
%defattr(-,root,root,755)
%{_bindir}/tpic2pdftex

%files ttfutils-bin
%defattr(-,root,root,755)
%{_bindir}/ttf2afm
%{_bindir}/ttf2pk
%{_bindir}/ttf2tfm
%{_bindir}/ttfdump

%files typeoutfileinfo-bin
%defattr(-,root,root,755)
%{_bindir}/typeoutfileinfo

%files ulqda-bin
%defattr(-,root,root,755)
%{_bindir}/ulqda

%files uptex-bin
%defattr(-,root,root,755)
%{_bindir}/euptex
%{_bindir}/upbibtex
%{_bindir}/updvitomp
%{_bindir}/updvitype
%{_bindir}/uplatex
%{_bindir}/upmpost
%{_bindir}/uppltotf
%{_bindir}/uptex
%{_bindir}/uptftopl
%{_bindir}/wovp2ovf

%files urlbst-bin
%defattr(-,root,root,755)
%{_bindir}/urlbst

%files vlna-bin
%defattr(-,root,root,755)
%{_bindir}/vlna

%files vpe-bin
%defattr(-,root,root,755)
%{_bindir}/vpe

%files web-bin
%defattr(-,root,root,755)
%{_bindir}/tangle
%{_bindir}/weave

%files xdvi-bin
%defattr(-,root,root,755)
%{_bindir}/xdvi
%{_bindir}/xdvi-xaw3d

%files xetex-bin
%defattr(-,root,root,755)
%{_bindir}/teckit_compile
%{_bindir}/xdvipdfmx
%{_bindir}/xelatex
%{_bindir}/xetex

%files xmltex-bin
%defattr(-,root,root,755)
%{_bindir}/pdfxmltex
%{_bindir}/xmltex

%files yplan-bin
%defattr(-,root,root,755)
%{_bindir}/yplan

%files -n libkpathsea6
%defattr(-,root,root,755)
%{_libdir}/libkpathsea*.so.*

%files -n %{name}-kpathsea-devel
%defattr(-,root,root)
%dir %{_includedir}/kpathsea
%{_includedir}/kpathsea/*
%{_libdir}/libkpathsea.so
%{_libdir}/pkgconfig/kpathsea.pc

%files -n libptexenc1
%defattr(-,root,root,755)
%{_libdir}/libptexenc*.so.*

%files -n %{name}-ptexenc-devel
%defattr(-,root,root)
%dir %{_includedir}/ptexenc
%{_includedir}/ptexenc/*
%{_libdir}/libptexenc.so
%{_libdir}/pkgconfig/ptexenc.pc

%files -n libsynctex1
%defattr(-,root,root,755)
%{_libdir}/libsynctex.so.*

%files -n %{name}-synctex-devel
%defattr(-,root,root)
%dir %{_includedir}/synctex/
%{_includedir}/synctex/*.h
%{_libdir}/libsynctex.so
%{_libdir}/pkgconfig/synctex.pc

%files -n libtexlua52-5
%defattr(-,root,root,755)
%{_libdir}/libtexlua[0-9]*so.*

%files -n %{name}-texlua-devel
%defattr(-,root,root)
%dir %{_includedir}/texlua[0-9]*/
%{_includedir}/texlua[0-9]*/*.h*
%{_libdir}/libtexlua[0-9]*so
%{_libdir}/pkgconfig/texlua[0-9]*.pc

%if %{with LuaJIT}
%files -n libtexluajit2
%defattr(-,root,root,755)
%{_libdir}/libtexluajit.so.*

%files -n %{name}-texluajit-devel
%defattr(-,root,root)
%dir %{_includedir}/texluajit/
%{_includedir}/texluajit/*.h*
%{_libdir}/libtexluajit.so
%{_libdir}/pkgconfig/texluajit.pc
%endif

%files -n %{name}-bin-devel
%defattr(-,root,root,755)

%if %{with buildbiber}
%if 0%{suse_version} > 1230
%files -n perl-biber -f perl-biber.files
%defattr(-,root,root,755)
%endif
%endif

%changelog
* Wed Apr 13 2016 werner@suse.de
- Use some more system libraries
- Avoid to prerequire own packages at build time
* Wed Apr 13 2016 schwab@suse.de
- Use system libmpfr
* Tue Apr 12 2016 werner@suse.de
- Work around broken perl_gen_filelist rpm macro
* Wed Mar 30 2016 werner@suse.de
- Change Recommends for binary packages on their main packages
  to Requires(pre) even if we get a dependency loop as otherwise
  some developers to not get it right.
- Add some basic Recommends for binary packages to have an
  basic environment around.
* Mon Mar 21 2016 werner@suse.de
- Really require the library packages with texive-bin-devel
* Sat Mar  5 2016 werner@suse.de
- Fix version template to get version of libtexlua52 right
* Fri Mar  4 2016 werner@suse.de
-  Split off shared libraries and the development headers for
  synctex, lua52, and luajit as separate packages.
* Tue Feb  9 2016 kruber@zib.de
- new perl-biber also requires perl module Text::Roman
* Tue Feb  9 2016 werner@suse.de
- Let texlive-ps2pk Obsoletes texlive-ps2pkm (boo#965472)
* Mon Feb  8 2016 werner@suse.de
- Also enforce fmtutil.pl to use FHS as then it will find mktexlsr.pl
  boo#965151
* Thu Feb  4 2016 werner@suse.de
- Fix bug boo#965151 that is wrong perl syntax
* Wed Feb  3 2016 werner@suse.de
- Make it build even on Leap with old perl 5.18.2
* Tue Feb  2 2016 werner@suse.de
- On older systems the linpoppler is somewhat to old
* Tue Feb  2 2016 werner@suse.de
- Be aware that LuaJIT does not build on all architectures
* Thu Jan 28 2016 werner@suse.de
- Update to TeXLive 2015 (timestamp 20150521 revision 26946)
  * Remove the now included patches
    biber-decode.diff
    biber-noreadonly.diff
    biblatex-biber-1.8.tar.xz
    source-asymptote-gs9.15.dif
  * Readd patch biber-certs.dif
    as we do not ship perls Motilla:CA
  * Add upstream patches
    biber-perl-unicode-normalize.dif
    biber-skip-bibtex-forms.dif
  * Add patch source-missed-scripts.dif to work around missed
    symbolic linked scripts
  * Adopted the following patches
    biber-perl-5.18.2.dif becomes biber-perl-5.22.dif
    biblatex-encoding.dif
    source-configure.dif
    source-dvipng.dif
    source-dviutils.dif
    source-lacheck.dif
    source-overflow.dif
    source-warns.dif
    source-x11r7.dif
    source.dif
* Tue Jul 14 2015 werner@suse.de
- Add patch biber-perl-5.22.dif to make regular expressions work
  even with perl 5.22 (boo#938018, patch by Friedrich Haubensak)
* Fri Apr 17 2015 werner@suse.de
- Port the patch set 'remove or clarify "nosell" material' from
  upstream to TeXlive source tar ball of 2014 (bsc#926106)
* Wed Apr  1 2015 werner@suse.de
- Add patch source-asymptote-gs9.15.dif to switch from espwrite
  device to eos2write device of ghostscript (boo#912398)
* Tue Mar 31 2015 werner@suse.de
- Luajittex does only compile on Intel, PPC, and ARM_LE (EABI)
* Thu Mar 26 2015 werner@suse.de
- Update to TeXLive 2014 (timestamp 20140525 revision 34252)
  * Support DVIPDFMx
  * [fix] avoid luatex crash under math_mode 'decimal'
  * luaotfload: Fix incorrect handling of font file formats luaotfload)
  * Sync with Context beta as of 2014-04-05
  * pdfTeX: sync with Knuth TeX 3.14159265, e-TeX 2.6
  * Many more ...
- Update biblatex-biber to 1.8
- Add upstrema patch
  source-xdvik-events.dif
  to make Xaw3d work
- Remove the now included patches
    biber-av.patch
    biber-certs.dif
    biber-dev.patch
    source-asymptote.dif
    source-bnc856363.dif
    source-dvipdfmx.dif
    source-poppler-0.26.patch
    source-psutils-flip.dif
- Adapted the following patches
    biber-decode.diff
    biber-noreadonly.diff
    biblatex-encoding.dif
    source-64.dif
    source-arraysubs.dif
    source-configure.dif
    source-dviutils.dif
    source-lacheck.dif
    source-poppler.dif
    source-psutils.dif
    source-texdoc.dif
    source-warns.dif
    source-x11r7.dif
    source-xdvizilla.dif
    source.dif
* Sun Mar 15 2015 jengelh@inai.de
- Remove redundant ldconfig requires
* Sat Dec 13 2014 Led <ledest@gmail.com>
- fix shebang of xdvi script: option '-a' of 'exec' command may be
  unsupported in some POSIX-complete shells
- update patches:
  * source.dif
* Tue Nov 11 2014 toddrme2178@gmail.com
- Make pdfjam-bin subpackage obsolete the older pdfjam package.
  These two packages provide the same binaries.
* Tue Jul 15 2014 mls@suse.de
- Add biber-decode.diff: Fix build with perl-5.20.0, where
  Encode::decode_utf8 no longer short-circuits if the input
  is already utf8.
* Tue May 20 2014 schwab@suse.de
- Make sure that texconfig/update is run only once per transaction
* Fri May  2 2014 werner@suse.de
- Correct patch number scheme of latest change
* Wed Apr 30 2014 dimstar@opensuse.org
- Add source-poppler-0.26.patch: Fix build with poppler 0.26:
  with poppler commit e04cab, there was an API break. Apply patch
  onlt when building against poppler 0.26 or newer.
* Fri Jan 31 2014 rschweikert@suse.com
- The Perl Readonly module changes semantics with version 1.04 such that
  Readonly variables are read only across contexts. Therefore using
  a read only variable as an XML namespace context name triggers an
  error when the context gets unregistered and an attempt is made to
  reset the variable.
  ~ add patch biber-noreadonly.diff to address the issue
* Sat Jan 25 2014 coolo@suse.com
- remove buildrequire kernel-devel, there are no kmps in here
* Mon Jan 13 2014 werner@suse.de
- Add upstream patch source-dvipdfmx.dif
  to avoid trouble with big endian
- Extend patch source-configure.dif to change package name for
  dvipdfmx (bnc#858412)
* Fri Dec 20 2013 werner@suse.de
- Add patch
  source-bnc856363.dif
  from upstream CVS to fix bnc#856363 - xdvi -sourceposition exits
  with Fatal error: currinf.set_char_p...
  compare with https://sourceforge.net/p/xdvi/bugs/388/
* Wed Nov 13 2013 werner@suse.de
- Make biber a simple perl script that is provide a new package
  perl-biber for the library files
* Mon Oct 28 2013 werner@suse.de
- Tar is now squeamishly with create and same order option
* Thu Sep 26 2013 werner@suse.de
- Correct SELFAUTODIR and SELFAUTOPARENT
* Wed Sep 25 2013 werner@suse.de
- Be aware that texlive scripts are now in the packages them self
* Mon Sep  9 2013 werner@suse.de
- Do not install duplicate files as already removed from file list
* Thu Sep  5 2013 werner@suse.de
- Remove `config(ca-certificates)' requirement and recommend
  ca-certificates as well as ca-certificates-mozilla
- Remove duplicate files from file list of musixtex
* Mon Sep  2 2013 werner@suse.de
- Add patch biber-av.patch form upstream to avoid Data::Diver perl
  module and use autovivification
* Tue Aug 20 2013 mvyskocil@suse.com
- Drop t1lib from dependencies as xdvi uses FreeType
- add few %%dir to filelist to fix a build
* Thu Aug  8 2013 werner@suse.de
- Do not override TEXMFLOCAL with TEXMFMAIN as this is now TEXMFDIST
* Thu Aug  8 2013 werner@suse.de
- Add patch biblatex-encoding.dif - explicite load PerlIO::encoding
  for output files, seems to be required for our perl (bnc#833815)
* Wed Aug  7 2013 werner@suse.de
- Repair several wrong paths cause by the move of TEXMFMAIN that is
  + the location of TLUtils.pm used by updmap
  + the location of xasy.py
- Help aysmptote configure script to detect libOSMesa with the
  implicite dependcy to libglapi which now provides the offscreen
  feature of aysmptote
* Tue Aug  6 2013 werner@suse.de
- Reset development version string with current version
* Mon Aug  5 2013 werner@suse.de
- Make sure that TEXMFMAIN is /usr/share/texmf now
* Thu Aug  1 2013 werner@suse.de
- Be aware that for older oepnSUSE there is no libOSMesa-devel
  but a Mesa-devel for libOSMesa.so
* Tue Jul 30 2013 werner@suse.de
- Update to TeXLive 2013 (timestamp 20130620)
  + Distribution layout: the top-level texmf/ directory has been
    merged into texmf-dist/, for simplicity. Both the TEXMFMAIN
    and TEXMFDIST Kpathsea variables now point to texmf-dist.
  + Many small language collections have been merged together,
    to simplify installation.
  + MetaPost: native support for PNG output and floating-point
    (IEEE double) has been added.
  + LuaTEX: updated to Lua 5.2, and includes a new library
    (pdfscanner) to process external PDF page content, among
    much else (see its web pages).
  + XeTEX (also see its web pages for more):
    The HarfBuzz library now used for font layout instead of ICU.
    Graphite2 and HarfBuzz are used instead of SilGraphite for Graphite layout.
    On Macs, Core Text is used instead of the (deprecated) ATSUI.
    Prefer TrueType/OpenType fonts to Type1 when the names are the same.
    Fix occasional mismatch in font finding between XeTEX and xdvipdfmx.
    Support OpenType math cut-ins.
  + xdvi: now uses FreeType instead of t1lib for rendering.
  + microtype.sty: some support for XeTEX (protrusion) and LuaTEX
    (protrusion, font expansion, tracking), among other enhancements.
- Update biblatex-biber to 1.7
- Udpate biblatex of TeXLive 2013 to 2.7a
- Remove source-binary-open.dif as now upstream
- Remove source-xdvi-xkbbell.dif as now upstream
- Add biber-certs.dif to use system certificates instead of Mozilla CA
- Add biber-dev.patch to make  biblatex-biber work with perl 5.18.0
- Modify source-64.dif, source-asymptote.dif, source-poppler.dif,
  source-texdoc.dif, source-warns.dif, and source.dif to make it
  compile.
* Wed Jul 17 2013 werner@suse.de
- Use PreReq for own packages instead of Requires(prereq)
* Tue Jul 16 2013 werner@suse.de
- Let texlive-biber require perl(LWP::UserAgent) to be able to
  read system based certificates
- New rpm had removed "prereq" flag from installation script bits
  that is that `Requires(prereq)' is not valid anymore :(((
* Thu May 16 2013 mhrusecky@suse.cz
- backward compatibility Provides: texlive-bin-dvilj (SR#175836)
* Tue May  7 2013 werner@suse.de
- As lcdf-typetools does not support kpathsea nor search below
  texmf tree build the texlive-lcdftypetools(-bin) packages again
  and let them conflict with the lcdf-typetools package.
* Fri May  3 2013 werner@suse.de
- Let texlive-pdfjam require texlive-pdfpages (bnc#814804)
- Let texlive-pdftools require texlive-pst-pdf (bnc#812286)
- Correct license boolean for biber packages
- Let texlive-tex4ht-bin conflict with ht due path /usr/bin/ht
- Let texlive-lcdftypetools(-bin) packages depend on lcdf-typetools
  package or conflict.
* Wed Mar 27 2013 werner@suse.de
- Change Obsoletes from < 2012+subversion to <= 2011 (bnc#811162)
- Let mathdesign require tex(texnansi.enc) (bnc#808731)
- Let biber-bin require perl(Text::BibTeX) (bnc#811258)
- Do not require xfs as we do not use xfs at all, otherwise we
  have to add some more lua code in the %%post scriptlet.
* Thu Feb 21 2013 werner@suse.de
- Add patch source-xdvi-xkbbell.dif from upstream to add aupport for
  XkbBell, fix bugs in handling source specials on 64bit systems,
  and allow mksedscript to handle macro values containing spaces.
* Tue Feb  5 2013 werner@suse.de
- Work around missing support of %%posttrans scriptlets in libzypp
  due missing rpm option for not to execute those scriptlets (bnc#773575)
* Fri Dec 21 2012 werner@suse.de
- remove conflicting libicu buildrequires as required by the arm
  people (was SR#146133)
* Wed Jun 27 2012 werner@suse.de
- Re-add the rungs script to dvipdfmx-bin
* Tue Jun 26 2012 werner@suse.de
- Do not open pipes in binary mode on POSIX systems
* Tue Jun 26 2012 werner@suse.de
- Avoid dependency loop between tex and texlive main package
- Set a recommendation to scheme-medium
* Mon Jun 25 2012 werner@suse.de
- Do not remove /var/run/texlive
* Fri Jun 22 2012 werner@suse.de
- The new updmap requires the perl mudules TLConfig.pm and TLUtils.pm
* Wed Jun 20 2012 werner@suse.de
- Make real package split between binary texlive and noarch
  texlive-filesystem and its collection/scheme packages
* Wed Jun 20 2012 werner@suse.de
- Avoid to be fooled by wrong ownerships during fmtutil that is
  allow user nobody and group mktex to access the temporary
  fmtutil directory if the initial user is root
* Tue Jun 19 2012 werner@suse.de
- Move old SuSEconfig md5 backup files to new location
* Tue Jun 19 2012 werner@suse.de
- Add missed /var/lib/texmf/web2c/ tree to file system
* Mon Jun 18 2012 werner@suse.de
- Simplify dependency chain(s)
* Thu Jun 14 2012 werner@suse.de
- Make RPMlint happy again
* Thu Jun 14 2012 werner@suse.de
- Correct version numbers of kpathsea and ptexenc automatically
* Wed Jun 13 2012 werner@suse.de
- Readd well known paclages like texlive-devel, texlive-bin-devel,
  and texlive-tools.  Also cause texlive-latex to install its
  binary packages.
* Tue Jun 12 2012 werner@suse.de
- Update to frozen/final 2012 (timestamp 20120611)
* Tue Jun 12 2012 werner@suse.de
- Do not drop the tar scheme and collection tar balls for reference
- Split off texlive-filesystem, texlive-scheme, and texlive-collection
  build into a separate spec file
- Make version comparision work as we use upstream version and
  release numbers
* Sat Jun  9 2012 coolo@suse.com
- relax the version requirements
* Fri Jun  8 2012 coolo@suse.com
- split out collections and filesystem
* Mon Jun  4 2012 werner@suse.de
- Avoid source url for all tar balls as our checkin script can not
  handle snapshots nor is knowing about the infrastructure of the
  upstream TeXLive server
* Fri Jun  1 2012 werner@suse.de
- Change also version/release scheme of the sub binary subpackages
* Thu May 31 2012 werner@suse.de
- Change version/release scheme
* Tue May 22 2012 werner@suse.de
- Install manaul page of biber as this is also build
- Require the used perl version for biber
* Mon May 21 2012 werner@suse.de
- Try to support BibteX-Biber perl dumped binary required to
  provide BibteX-Biber also for PPC nad PPC64
* Fri May 18 2012 werner@suse.de
- Use texlive.texlive instead of texlive.texmf for permission file
* Fri May 18 2012 werner@suse.de
- Be aware new poppler library, there is no getSize() but only
  getNumObjects()
* Mon May 14 2012 werner@suse.de
- Cron: remove older sources as well as crap
* Mon May 14 2012 werner@suse.de
- Avoid warning messages from mktexlsr due empty ls-R
- Handle case where public program is not setgid public
- Make spec file more flexible and use a rpm macro for a public
  group which can be named to e.g. public
* Mon May 14 2012 werner@suse.de
- If MT_FEATURES includes varfonts and system default is not
  writable choose $HOME/.cache/texmf/fonts
* Tue Dec 20 2011 werner@suse.de
- First initial main spec file using the original TeX Live packaging
  scheme and layout
